package COM.ibm.jaws.models.trs;


import java.util.*;
import java.net.*;

import COM.ibm.jaws.mofw.*;
import COM.ibm.jaws.services.filepobc.*;
import COM.ibm.jaws.services.bcfw.*;
import COM.ibm.jaws.services.sroot.*;
import COM.ibm.jaws.util.*;


public class AddTrip
{
    public static void
    main(String[] args)
    {
	Debug d = new Debug(null, true);

	if (args.length != 8) {
	    System.err.println("Usage: AddTrip baseDirectory userId " +
			       "userPassword name departureCity " +
			       "destinationCity departureDate returnDate");
	    System.exit(1);
	}


	String baseDirectory = args[0];
	String userId = args[1];
	String password = args[2];
	String tripName = args[3];
	String departureCity = args[4];
	String destinationCity = args[5];
	String departureDateString = args[6];
	String returnDateString = args[7];
	
	BaseCollection srootBC =
	    SimpleRootBC.getRoot(baseDirectory + "/" +
				 CommonBase.ApplicationSpace);

	BaseCollection applicationRoot =
	    (BaseCollection) srootBC.resolve("trsApplicationRoot");

	Session session = (Session) srootBC.resolve("session");

	User user = session.login(userId, password);

	user.addTrip(tripName,
		     departureCity, destinationCity,
		     new Date(departureDateString),
		     new Date(returnDateString));

	
	d.outln("----------------");
	d.outln("User:");
	d.outln("" + user);

	Iterator trips = null;
	if ((trips = user.getTrips()) == null) {
	    return;
	}

	Trip trip = null;
	while ((trip = (Trip) trips.getNext()) != null) {

	    if (trip.getName().equals(tripName) == false) {
		continue;
	    }

	    d.outln("----------------");
	    d.outln("New trip:");
	    d.outln("" + trip);
	    
	    Iterator flights = trip.getDepartureFlights("First class");
	    if (flights != null) {

		Flight flight = null;
		while ((flight = (Flight) flights.getNext()) != null) {
		    
		    d.outln("Reserving departure flight.");
		    trip.reserveDepartureFlight(flight,
						1,
						"B2");
		    break;

// 		    d.outln("--------");
// 		    d.outln("Matching flight: ");
// 		    d.outln(flight.getFlightPlan().
// 			    getAirlineCompany().getName());
// 		    d.outln(flight.getFlightPlan().
// 			    getDepartureAirport().getName() +
// 			    " to " + 
// 			    flight.getFlightPlan().
// 			    getDestinationAirport().getName());
// 		    d.outln(" " + flight);
		}
	    }


	    flights = trip.getReturnFlights("First class");
	    if (flights != null) {

		Flight flight = null;
		while ((flight = (Flight) flights.getNext()) != null) {

		    d.outln("Reserving return flight.");
		    trip.reserveReturnFlight(flight,
					     1,
					     "C2");
		    break;

// 		    d.outln("--------");
// 		    d.outln("Matching flight: ");
// 		    d.outln(flight.getFlightPlan().
// 			    getAirlineCompany().getName());
// 		    d.outln(flight.getFlightPlan().
// 			    getDepartureAirport().getName() +
// 			    " to " + 
// 			    flight.getFlightPlan().
// 			    getDestinationAirport().getName());
// 		    d.outln("" + flight);
		}
	    }


	    Iterator roomGroups = trip.getRoomGroups(100);
	    if (roomGroups != null) {

		RoomGroup roomGroup = null;
		while ((roomGroup =
			(RoomGroup) roomGroups.getNext()) != null) {
		    
		    d.outln("Reserving hotel.");
		    trip.reserveHotel(roomGroup, 1);
		    break;

// 		    d.outln("--------");
// 		    d.outln("Matching room group: ");
// 		    d.outln(roomGroup.getHotelCompany().getName());
// 		    d.outln(" " + roomGroup);
		}
	    }
	    

	    Iterator carFleets = trip.getCarFleets("Economy");
	    if (carFleets != null) {
		CarFleet carFleet = null;
		while ((carFleet =
			(CarFleet) carFleets.getNext()) != null) {

		    d.outln("Reserving car.");
		    trip.reserveCar(carFleet, 1);
		    break;

// 		    d.outln("-----------------------------");
// 		    d.outln("CarFleet:");
// 		    d.outln("" + carFleet.getCarRentalCompany().
// 			    getName());
// 		    d.outln("" +
// 			    carFleet.getAirport().getCity().getName());
// 		    d.outln("" + carFleet);
		}
	    }

	    break;
	}

	d.outln("--------------------------------------------------");
	d.outln("Reservation listing:");
	d.outln("");

	trips = null;
	if ((trips = user.getTrips()) == null) {
	    return;
	}

	trip = null;
	while ((trip = (Trip) trips.getNext()) != null) {

	    if (trip.getName().equals(tripName) == false) {
		continue;
	    }

	    FlightReservation flightReservation = null;

	    if ((flightReservation =
		 trip.getDepartureFlightReservation()) != null) {

		d.outln("Departure flight reservation:");
		d.outln("" + flightReservation.getFlight().
			getFlightPlan().getFlightNumber());
		d.outln("" + flightReservation.getFlight().
			getDepartureDateTime());
		d.outln("" + flightReservation);
		d.outln("" + flightReservation);
	    }
	    

	    if ((flightReservation =
		 trip.getReturnFlightReservation()) != null) {
		
		d.outln("Return flight reservation:");
		d.outln("" + flightReservation.getFlight().
			getFlightPlan().getFlightNumber());
		d.outln("" + flightReservation.getFlight().
			getDepartureDateTime());
		d.outln("" + flightReservation);
		d.outln("" + flightReservation.getConfirmationNumber());
		d.outln("" + flightReservation);
	    }
	    

	    HotelReservation hotelReservation = null;
	    if ((hotelReservation = trip.getHotelReservation()) != null) {
		d.outln("Hotel reservation:");
		d.outln("" + hotelReservation.getRoomGroup().
			getHotelCompany().getName());
		d.outln("" + hotelReservation.getRoomGroup().getName());
		d.outln("" + hotelReservation.getConfirmationNumber());
		d.outln("" + hotelReservation);
	    }


	    CarReservation carReservation = null;
	    if ((carReservation = trip.getCarReservation()) != null) {
		d.outln("Car reservation:");
		d.outln("" + carReservation.getCarFleet().
			getCarRentalCompany().getName());
		d.outln("" + carReservation.getCarFleet().getName());
		d.outln("" + carReservation.getConfirmationNumber());
		d.outln("" + carReservation);
	    }
	}

	srootBC.release();
    }
}
