package COM.ibm.jaws.models.trs;


import java.net.*;
import COM.ibm.jaws.mofw.*;


abstract public class AirlineCompanyBase extends CommonBase
{
    protected String name = null;
    protected Contact contact = null;
    protected ReferenceCollection planeRC = null;
    protected ReferenceCollection flightPlanRC = null;


    public
    AirlineCompanyBase()
    {
    }


    public
    AirlineCompanyBase(String name)
    {
	this.name = name;
    }


    public Contact
    addContact(String address1,
	       String address2,
	       String city,
	       String zip,
	       String phoneAreaCode,
	       String phoneNumber,
	       String faxAreaCode,
	       String faxNumber,
	       String emailId,
	       String emailAddress,
	       URL url)
    {
	Contact contactManageable =
	    new ContactImpl(self,
			    address1, address2,
			    city, zip,
			    phoneAreaCode, phoneNumber,
			    faxAreaCode, faxNumber,
			    emailId, emailAddress, url);

	contact =
	    (Contact) contactBC().createFromCopy(null,
						 contactManageable,
						 null);

	return contact;
    }


    public Contact
    getContact()
    {
	return contact;
    }


    public String
    getName()
    {
	return name;
    }


    public Plane
    addPlane(String name,
	     String planeImage,
	     String seatImage,
	     int totalSeats)
    {
	// Implement the lazy create for the local trip reference collection
	// if this is the first trip added for this user.
	if (planeRC == null) {
	    planeRC = (ReferenceCollection)
		airlinePlaneRCBC().createFromCopy(null, null, null);
	}

	// New up the manageable trip object.
	Plane plane = new PlaneImpl(name, planeImage, seatImage, totalSeats);

	// Resolve the application's credit card base collection, and add the
	// credit card to the BC, managing it.
	Plane planeManaged =
	    (Plane) planeBC().createFromCopy(name, plane, null);


	// Insert the managed trip into the local reference collection.
	planeRC.insertElement(planeManaged);

	return planeManaged;
    }


    public Iterator
    getPlanes()
    {
	return planeRC.evaluate(null, "MOFW::objects");
    }


    public FlightPlan
    addFlightPlan(String flightNumber,
		  String departureAirportString,
		  String destinationAirportString,
		  float price)
    {
	// Implement the lazy create for the local trip reference collection
	// if this is the first trip added for this user.
	if (flightPlanRC == null) {
	    flightPlanRC = (ReferenceCollection)
		airlineFlightPlanRCBC().createFromCopy(null, null, null);
	}

	// New up the manageable trip object.
	FlightPlan flightPlan = new FlightPlanImpl(this,
						   flightNumber,
						   price);

	// Resolve the application's credit card base collection, and add the
	// credit card to the BC, managing it.
	FlightPlan flightPlanManaged =
	    (FlightPlan) flightPlanBC().createFromCopy(null, flightPlan, null);


	// Unable to do this until the  object is managed because these
	// routines rely on a dependent context to be able to resolve the
	// airport string into an airport reference.
	flightPlanManaged.setDepartureAirport(departureAirportString);
	flightPlanManaged.setDestinationAirport(destinationAirportString);


	// Insert the managed trip into the local reference collection.
	flightPlanRC.insertElement(flightPlanManaged);

	return flightPlanManaged;
    }


    public Iterator
    getFlightPlans()
    {
	return flightPlanRC.evaluate(null, "MOFW::objects");
    }


    public String
    toString()
    {
	return
	    "Name: " + name + "\n";
    }
}
