package COM.ibm.jaws.models.trs;


import COM.ibm.jaws.mofw.*;
import java.util.*;
import java.net.*;


abstract public class CarFleetBase extends CommonBase
{
    protected Object carRentalCompany = null;

    protected Airport airport = null;
    protected String airportCodeString = null;

    protected String name = null;
    protected float price = (float) 0;

    protected String location = null;
    protected Contact contact = null;

    protected Car car = null;
    protected String carString = null;

    protected ReferenceCollection carFleetCarFleetAvailabilityRC = null;
    protected ReferenceCollection carReservationRC = new RCImpl();


    public
    CarFleetBase()
    {
    }


    public
    CarFleetBase(Object carRentalCompany,
		 String airportCodeString,
		 String name,
		 String carString,
		 float price)
    {
	this.carRentalCompany = carRentalCompany;
	this.airportCodeString = airportCodeString;
	this.name = name;
	this.carString = carString;
	this.price = price;
    }


    public void
    activate()
    {
	if (airportCodeString != null) {
	    setAirport(airportCodeString);
	    airportCodeString = null;
	}

	if (carString != null) {
	    setCar(carString);
	    carString = null;
	}
    }



    public Contact
    addContact(String address1,
	       String address2,
	       String city,
	       String zip,
	       String phoneAreaCode,
	       String phoneNumber,
	       String faxAreaCode,
	       String faxNumber,
	       String emailId,
	       String emailAddress,
	       URL url)
    {
	Contact contactManageable =
	    new ContactImpl(self,
			    address1, address2,
			    city, zip,
			    phoneAreaCode, phoneNumber,
			    faxAreaCode, faxNumber,
			    emailId, emailAddress, url);

	contact =
	    (Contact) contactBC().createFromCopy(null,
						 contactManageable,
						 null);

	return contact;
    }



    public boolean
    available(Date pickupDate,
	      Date dropoffDate)
    {
	int pickupYear = pickupDate.getYear();
	int pickupMonth = pickupDate.getMonth();
	int pickupDay = pickupDate.getDate();

	Date date = new Date(pickupYear, pickupMonth, pickupDay);
	while (date.before(dropoffDate) || date.equals(dropoffDate)) {
	    if (carAvailable(date) == false) {
		return false;
	    }
	    date = new Date(pickupYear, pickupMonth, ++pickupDay);
	}

	return true;
    }


    public void
    cancel(CarReservation res)
    {
	//@BC
	System.out.println("CarFleetBase::cancel(CarReservation res)");
	System.out.println("  removing reservation from RC = <<" + res + ">>");
	System.out.println("  res.getTrip() = <<" + res.getTrip() + ">>");

/*
	Iterator carReservations = null;
	if ((carReservations =
	     carReservationRC.evaluate(null, "MOFW::objects")) == null) {
	    return;
	}

	CarReservation carReservation = null;
	while ((carReservation =
		(CarReservation) carReservations.getNext()) != null) {
	    if (carReservation.getConfirmationNumber() ==
		res.getConfirmationNumber()) {

		carReservationRC.removeElement(carReservation);
		break;
	    }
	}
*/

	Date arrivalDate = res.getTrip().getDepartureDate();
	Date departureDate = res.getTrip().getReturnDate();

	int arrivalYear = arrivalDate.getYear();
	int arrivalMonth = arrivalDate.getMonth();
	int arrivalDay = arrivalDate.getDate();

	Date date = new Date(arrivalYear, arrivalMonth, arrivalDay);
	while (date.before(departureDate) || date.equals(departureDate)) {
	    carFleetAvailbilityCancel(date);
	    date = new Date(arrivalYear, arrivalMonth, ++arrivalDay);
	}

	//@BC
	System.out.println("  removing reservation from RC = <<" + res + ">>");
	carReservationRC.removeElement(res);

    }


    public void
    carFleetAvailbilityCancel(Date date)
    {
	Iterator carFleetAvailabilities = null;
	if ((carFleetAvailabilities = getCarFleetAvailabilities()) == null) {
	    return;
	}

	CarFleetAvailability carFleetAvailability = null;
	while ((carFleetAvailability = (CarFleetAvailability)
		carFleetAvailabilities.getNext()) != null) {

	    if (carFleetAvailability.getDate().equals(date)) {
		carFleetAvailability.cancel();
		return;
	    }
	}
    }


    public Airport
    getAirport()
    {
	return airport;
    }


    public Car
    getCar()
    {
	return car;
    }


    public CarRentalCompany
    getCarRentalCompany()
    {
	return (CarRentalCompany) carRentalCompany;
    }


    public CarFleetAvailability
    addCarFleetAvailability(Date date,
			    int totalAvailableCars)
    {
	if (carFleetCarFleetAvailabilityRC == null) {
	    carFleetCarFleetAvailabilityRC = (ReferenceCollection)
		carFleetCarFleetAvailabilityRCBC().createFromCopy(null,
								  null,
								  null);
	}

	CarFleetAvailability carFleetAvailability =
	    new CarFleetAvailabilityImpl(this,
					 date,
					 totalAvailableCars);

	CarFleetAvailability carFleetAvailabilityManaged =
	    (CarFleetAvailability)
	    carFleetAvailabilityBC().createFromCopy(null,
						    carFleetAvailability,
						    null);

	carFleetCarFleetAvailabilityRC.insertElement
	    (carFleetAvailabilityManaged);

	return carFleetAvailabilityManaged;
    }


    public Contact
    getContact()
    {
	return contact;
    }


    public String
    getLocation()
    {
	return location;
    }


    public String
    getName()
    {
	return name;
    }


    public float
    getPrice()
    {
	return price;
    }


    public void
    reserve(CarReservation carReservation)
    {
	carReservationRC.insertElement(carReservation);

	Date pickupDate = carReservation.getTrip().getDepartureDate();
	Date dropoffDate = carReservation.getTrip().getReturnDate();

	int pickupYear = pickupDate.getYear();
	int pickupMonth = pickupDate.getMonth();
	int pickupDay = pickupDate.getDate();

	Date date = new Date(pickupYear, pickupMonth, pickupDay);
	while (date.before(dropoffDate) || date.equals(dropoffDate)) {
	    reserveCarFromGroup(date);
	    date = new Date(pickupYear, pickupMonth, ++pickupDay);
	}
    }


    public Iterator
    getCarFleetAvailabilities()
    {
	return carFleetCarFleetAvailabilityRC.evaluate(null, "MOFW::objects");
    }


    public void
    setAirport(String airportCode)
    {
	if ((airport = (Airport) airportBC().resolve(airportCode)) == null) {
	    throw new RuntimeException();
	}
    }


    public void
    setCar(String carString)
    {
	if ((car = (Car) carBC().resolve(carString)) == null) {
	    throw new RuntimeException();
	}
    }


    public String
    toString()
    {
	return
	    "Name: " + name + "\n" +
	    "Price: " + price + "\n";
    }


    //----------------------------------------------------------------------
    // Protected methods


    protected boolean
    carAvailable(Date date)
    {
	Iterator carFleetAvailabilities = null;
	if ((carFleetAvailabilities = getCarFleetAvailabilities()) == null) {
	    return false;
	}

	CarFleetAvailability carFleetAvailability = null;
	while ((carFleetAvailability = (CarFleetAvailability)
		carFleetAvailabilities.getNext()) != null) {

	    if (carFleetAvailability.getDate().equals(date) &&
		carFleetAvailability.getTotalAvailableCars() > 0) {
		return true;
	    }
	}

	return false;
    }


    protected void
    reserveCarFromGroup(Date date)
    {
	Iterator carFleetAvailabilities = null;
	if ((carFleetAvailabilities = getCarFleetAvailabilities()) == null) {
	    return;
	}

	CarFleetAvailability carFleetAvailability = null;
	while ((carFleetAvailability = (CarFleetAvailability)
		carFleetAvailabilities.getNext()) != null) {

	    if (carFleetAvailability.getDate().equals(date)) {
		carFleetAvailability.reserve();
		break;
	    }
	}
    }
}
