package COM.ibm.jaws.models.trs;


import COM.ibm.jaws.mofw.BaseCollection;
import COM.ibm.jaws.services.filepobc.FilepoBCImpl;
import COM.ibm.jaws.services.sroot.SimpleRootBC;
import COM.ibm.jaws.services.sroot.SRootNC;
import COM.ibm.jaws.services.bcfw.Syncable;
import COM.ibm.jaws.services.bcfw.CacheManager;
import COM.ibm.jaws.services.lrucmgr.LruCacheManagerImpl;


public class CreateTables
{
    public static void
    main(String[] args)
    {
	if (args.length != 1) {
	    System.err.println("Usage: CreateTables baseDirectory\n");
	    System.err.println("The baseDirectory is where the activation" +
			       "space directory and the\n" +
			       "data directories will be located.");
	    System.exit(1);
	}

	String baseDirectory = args[0];


	// Create a named collection for the dependent context and add the
	// necessary entries into the dependent context.
	SRootNC dependentContext = new SRootNC();

	// Create the Simple Root base collection that allows multiple
	// servlets to attach to the same static activation space of TRS
	// base collections of data.
	BaseCollection srootBC =
	    new SimpleRootBC(baseDirectory +
			     "/" + CommonBase.ApplicationSpace,
			     dependentContext);
	    

	// Create a cache manager that is managed by sroot, and bind an
	// alias for it into the dependent context.  This cache manager is
	// used by the filepobc base collection for caching.
// 	CacheManager cacheManager = new LruCacheManagerImpl(100); 

// 	dependentContext.bind
// 	    ("COM.ibm.jaws.services.sroot::" +
// 	     "COM.ibm.jaws.services.lrucmgr.LruCacheManager",
// 	     "COM.ibm.jaws.services.lrucmgr.LruCacheManagerSRootMO");

// 	CacheManager cacheManagerManaged = (CacheManager)
// 	    srootBC.createFromCopy
// 	    ("cacheManager",
// 	     (COM.ibm.jaws.mofw.Manageable) cacheManager,
// 	     "COM.ibm.jaws.services.lrucmgr.LruCacheManager");

// 	dependentContext.bind("COM.ibm.jaws.services.bcfw.CacheManager",
// 			      cacheManager);
	
	Session session =
	    new SessionImpl();

	dependentContext.bind
	    ("COM.ibm.jaws.services.sroot::" +
	     "COM.ibm.jaws.models.trs.Session",
	     "COM.ibm.jaws.models.trs.SessionSRootMO");

	srootBC.createFromCopy
	    ("session",
	     session,
	     "COM.ibm.jaws.models.trs.Session");


	// Create the application root BC that will contain the normalized
	// BCs of all the model objects.  Have the Simple Root BC manage it
	// (which will be the only item in Simple Root BC), and add an alias
	// for the BC to the dependent context.
	BaseCollection applicationRoot =
	    new FilepoBCImpl(dataDir(baseDirectory,
				     CommonBase.ApplicationRootBC),
			     null);
	
	dependentContext.bind
	    ("COM.ibm.jaws.services.sroot::" +
	     "COM.ibm.jaws.services.filepobc.FilepoBC",
	     "COM.ibm.jaws.services.filepobc.FilepoBCSRootMO");

	BaseCollection applicationRootManaged =
	    (BaseCollection) srootBC.createFromCopy
	    ("trsApplicationRoot",
	     applicationRoot,
 	     "COM.ibm.jaws.services.filepobc.FilepoBC");
	
	// Create an alias for the application root in the dc.
	dependentContext.bind("TRS::ApplicationRootBC",
			      applicationRootManaged);
	
	

	createTablePerObject(baseDirectory,
			     dependentContext,
			     applicationRootManaged);


	createTablePerRC(baseDirectory,
			 dependentContext,
			 applicationRootManaged);


	srootBC.release();
    }


    public static void
    createTablePerObject(String baseDirectory,
			 SRootNC dependentContext,
			 BaseCollection applicationRootManaged)
    {
	// The interface used for managing the following BCs relies on
	// the dependent context entry binding filepobc::FilepoBC to a
	// managed filepoBC (FilepoBCFilepoManaged).
	dependentContext.bind
	    ("COM.ibm.jaws.services.filepobc::" +
	     "COM.ibm.jaws.services.filepobc.FilepoBC",
	     "COM.ibm.jaws.services.filepobc.FilepoBCFilepoManaged");



	BaseCollection airlineCompanyBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.AirlineCompanyBC),
	     "COM.ibm.jaws.models.trs.AirlineCompanyFilepoManaged");

	BaseCollection airlineCompanyBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("airlineCompanyBC",
	     airlineCompanyBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

 	dependentContext.bind(CommonBase.AirlineCompanyBC,
 			      airlineCompanyBCManaged);



	BaseCollection airportBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.AirportBC),
	     "COM.ibm.jaws.models.trs.AirportFilepoManaged");

	BaseCollection airportBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("airportBC",
	     airportBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

 	dependentContext.bind(CommonBase.AirportBC,
 			      airportBCManaged);



	BaseCollection flightReservationBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.FlightReservationBC),
	     "COM.ibm.jaws.models.trs.FlightReservationFilepoManaged");

	BaseCollection flightReservationBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("flightReservationBC",
	     flightReservationBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

 	dependentContext.bind(CommonBase.FlightReservationBC,
 			      flightReservationBCManaged);



	BaseCollection carBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.CarBC),
	     "COM.ibm.jaws.models.trs.CarFilepoManaged");

	BaseCollection carBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("carBC",
	     carBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

 	dependentContext.bind(CommonBase.CarBC,
 			      carBCManaged);



	BaseCollection carFleetBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.CarFleetBC),
	     "COM.ibm.jaws.models.trs.CarFleetFilepoManaged");

	BaseCollection carFleetBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("carFleetBC",
	     carFleetBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

 	dependentContext.bind(CommonBase.CarFleetBC,
 			      carFleetBCManaged);



	BaseCollection carFleetAvailabilityBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.CarFleetAvailabilityBC),
	     "COM.ibm.jaws.models.trs.CarFleetAvailabilityFilepoManaged");

	BaseCollection carFleetAvailabilityBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("carFleetAvailabilityBC",
	     carFleetAvailabilityBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

 	dependentContext.bind(CommonBase.CarFleetAvailabilityBC,
 			      carFleetAvailabilityBCManaged);



	BaseCollection carRentalCompanyBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.CarRentalCompanyBC),
	     "COM.ibm.jaws.models.trs.CarRentalCompanyFilepoManaged");

	BaseCollection carRentalCompanyBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("carRentalCompanyBC",
	     carRentalCompanyBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

 	dependentContext.bind(CommonBase.CarRentalCompanyBC,
 			      carRentalCompanyBCManaged);



	BaseCollection carReservationBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.CarReservationBC),
	     "COM.ibm.jaws.models.trs.CarReservationFilepoManaged");

	BaseCollection carReservationBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("carReservationBC",
	     carReservationBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

 	dependentContext.bind(CommonBase.CarReservationBC,
 			      carReservationBCManaged);



	BaseCollection cityBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.CityBC),
	     "COM.ibm.jaws.models.trs.CityFilepoManaged");

	BaseCollection cityBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("cityBC",
	     cityBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.CityBC,
			      cityBCManaged);



	BaseCollection confirmationBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.ConfirmationBC),
	     "COM.ibm.jaws.models.trs.ConfirmationFilepoManaged");

	BaseCollection confirmationBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("confirmationBC",
	     confirmationBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.ConfirmationBC,
			      confirmationBCManaged);



	BaseCollection contactBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.ContactBC),
	     "COM.ibm.jaws.models.trs.ContactFilepoManaged");

	BaseCollection contactBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("contactBC",
	     contactBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.ContactBC,
			      contactBCManaged);



	BaseCollection countryBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.CountryBC),
	     "COM.ibm.jaws.models.trs.CountryFilepoManaged");

	BaseCollection countryBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("countryBC",
	     countryBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.CountryBC,
			      countryBCManaged);



	BaseCollection creditCardBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.CreditCardBC),
	     "COM.ibm.jaws.models.trs.CreditCardFilepoManaged");

	BaseCollection creditCardBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("creditCardBC",
	     creditCardBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.CreditCardBC,
			      creditCardBCManaged);



	BaseCollection flightBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.FlightBC),
	     "COM.ibm.jaws.models.trs.FlightFilepoManaged");

	BaseCollection flightBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("flightBC",
	     flightBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.FlightBC,
			      flightBCManaged);



	BaseCollection flightPlanBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.FlightPlanBC),
	     "COM.ibm.jaws.models.trs.FlightPlanFilepoManaged");

	BaseCollection flightPlanBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("flightPlanBC",
	     flightPlanBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.FlightPlanBC,
			      flightPlanBCManaged);



	BaseCollection hotelCompanyBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.HotelCompanyBC),
	     "COM.ibm.jaws.models.trs.HotelCompanyFilepoManaged");

	BaseCollection hotelCompanyBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("hotelCompanyBC",
	     hotelCompanyBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.HotelCompanyBC,
			      hotelCompanyBCManaged);



	BaseCollection hotelReservationBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.HotelReservationBC),
	     "COM.ibm.jaws.models.trs.HotelReservationFilepoManaged");

	BaseCollection hotelReservationBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("hotelReservationBC",
	     hotelReservationBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

 	dependentContext.bind(CommonBase.HotelReservationBC,
 			      hotelReservationBCManaged);



	BaseCollection planeBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.PlaneBC),
	     "COM.ibm.jaws.models.trs.PlaneFilepoManaged");

	BaseCollection planeBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("planeBC",
	     planeBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

 	dependentContext.bind(CommonBase.PlaneBC,
 			      planeBCManaged);



	BaseCollection roomGroupBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.RoomGroupBC),
	     "COM.ibm.jaws.models.trs.RoomGroupFilepoManaged");

	BaseCollection roomGroupBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("roomGroupBC",
	     roomGroupBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

 	dependentContext.bind(CommonBase.RoomGroupBC,
 			      roomGroupBCManaged);



	BaseCollection roomGroupAvailabilityBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.RoomGroupAvailabilityBC),
	     "COM.ibm.jaws.models.trs.RoomGroupAvailabilityFilepoManaged");

	BaseCollection roomGroupAvailabilityBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("roomGroupAvailabilityBC",
	     roomGroupAvailabilityBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

 	dependentContext.bind(CommonBase.RoomGroupAvailabilityBC,
 			      roomGroupAvailabilityBCManaged);



	BaseCollection stateBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.StateBC),
	     "COM.ibm.jaws.models.trs.StateFilepoManaged");

	BaseCollection stateBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("stateBC",
	     stateBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.StateBC,
			      stateBCManaged);



	BaseCollection travelProfileBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.TravelProfileBC),
	     "COM.ibm.jaws.models.trs.TravelProfileFilepoManaged");

	BaseCollection travelProfileBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("travelProfileBC",
	     travelProfileBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.TravelProfileBC,
			      travelProfileBCManaged);



	BaseCollection tripBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.TripBC),
	     "COM.ibm.jaws.models.trs.TripFilepoManaged");

	BaseCollection tripBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("tripBC",
	     tripBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.TripBC,
			      tripBCManaged);



	BaseCollection userBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.UserBC),
	     "COM.ibm.jaws.models.trs.UserFilepoManaged");
	
	BaseCollection userBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("userBC",
	     userBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.UserBC,
			      userBCManaged);
    }


    public static void
    createTablePerRC(String baseDirectory,
		     SRootNC dependentContext,
		     BaseCollection applicationRootManaged)
    {
	// The interface used for managing the following BCs relies on
	// the dependent context entry binding filepobc::FilepoBC to a
	// managed filepoBC (FilepoBCFilepoManaged).
	dependentContext.bind
	    ("COM.ibm.jaws.services.filepobc::COM.ibm.jaws.models.trs.RC",
	     "COM.ibm.jaws.models.trs.RCFilepoManaged");



	BaseCollection airlineFlightPlanRCBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.AirlineFlightPlanRCBC),
	     "COM.ibm.jaws.models.trs.RCFilepoManaged");

	BaseCollection airlineFlightPlanRCBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("airlineFlightPlanRCBC",
	     airlineFlightPlanRCBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.AirlineFlightPlanRCBC,
			      airlineFlightPlanRCBCManaged);



	BaseCollection airlinePlaneRCBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.AirlinePlaneRCBC),
	     "COM.ibm.jaws.models.trs.RCFilepoManaged");

	BaseCollection airlinePlaneRCBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("airlinePlaneRCBC",
	     airlinePlaneRCBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.AirlinePlaneRCBC,
			      airlinePlaneRCBCManaged);



	BaseCollection carRentalCarRCBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.CarRentalCarRCBC),
	     "COM.ibm.jaws.models.trs.RCFilepoManaged");

	BaseCollection carRentalCarRCBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("carRentalCarRCBC",
	     carRentalCarRCBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.CarRentalCarRCBC,
			      carRentalCarRCBCManaged);



	BaseCollection carRentalCarFleetRCBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.CarRentalCarFleetRCBC),
	     "COM.ibm.jaws.models.trs.RCFilepoManaged");

	BaseCollection carRentalCarFleetRCBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("carRentalCarFleetRCBC",
	     carRentalCarFleetRCBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.CarRentalCarFleetRCBC,
			      carRentalCarFleetRCBCManaged);



	BaseCollection carFleetCarRCBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.CarFleetCarRCBC),
	     "COM.ibm.jaws.models.trs.RCFilepoManaged");

	BaseCollection carFleetCarRCBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("carFleetCarRCBC",
	     carFleetCarRCBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.CarFleetCarRCBC,
			      carFleetCarRCBCManaged);



	BaseCollection carFleetCarFleetAvailabilityRCBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.CarFleetCarFleetAvailabilityRCBC),
	     "COM.ibm.jaws.models.trs.RCFilepoManaged");

	BaseCollection carFleetCarFleetAvailabilityRCBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("carFleetCarFleetAvailabilityRCBC",
	     carFleetCarFleetAvailabilityRCBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.CarFleetCarFleetAvailabilityRCBC,
			      carFleetCarFleetAvailabilityRCBCManaged);



	BaseCollection flightPlanFlightRCBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.FlightPlanFlightRCBC),
	     "COM.ibm.jaws.models.trs.RCFilepoManaged");

	BaseCollection flightPlanFlightRCBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("flightPlanFlightRCBC",
	     flightPlanFlightRCBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.FlightPlanFlightRCBC,
			      flightPlanFlightRCBCManaged);



	BaseCollection hotelRoomRCBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.HotelRoomRCBC),
	     "COM.ibm.jaws.models.trs.RCFilepoManaged");

	BaseCollection hotelRoomRCBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("hotelRoomRCBC",
	     hotelRoomRCBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.HotelRoomRCBC,
			      hotelRoomRCBCManaged);



	BaseCollection roomGroupRoomGroupAvailabilityRCBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.RoomGroupRoomGroupAvailabilityRCBC),
	     "COM.ibm.jaws.models.trs.RCFilepoManaged");

	BaseCollection roomGroupRoomGroupAvailabilityRCBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("roomGroupRoomGroupAvailabilityRCBC",
	     roomGroupRoomGroupAvailabilityRCBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.RoomGroupRoomGroupAvailabilityRCBC,
			      roomGroupRoomGroupAvailabilityRCBCManaged);



	BaseCollection travelProfileCreditCardRCBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.TravelProfileCreditCardRCBC),
	     "COM.ibm.jaws.models.trs.RCFilepoManaged");

	BaseCollection travelProfileCreditCardRCBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("travelProfileCreditCardRCBC",
	     travelProfileCreditCardRCBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.TravelProfileCreditCardRCBC,
			      travelProfileCreditCardRCBCManaged);
	


	BaseCollection tripReservationRCBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.TripReservationRCBC),
	     "COM.ibm.jaws.models.trs.RCFilepoManaged");

	BaseCollection tripReservationRCBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("tripReservationRCBC",
	     tripReservationRCBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");

	dependentContext.bind(CommonBase.TripReservationRCBC,
			      tripReservationRCBCManaged);


	BaseCollection userTripRCBC =
	    new FilepoBCImpl
	    (dataDir(baseDirectory,
		     CommonBase.UserTripRCBC),
	     "COM.ibm.jaws.models.trs.RCFilepoManaged");

	BaseCollection userTripRCBCManaged =
	    (BaseCollection) applicationRootManaged.createFromCopy
	    ("userTripRCBC",
	     userTripRCBC,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");
	
	dependentContext.bind(CommonBase.UserTripRCBC,
			      userTripRCBCManaged);
    }


    public static String
    dataDir(String baseDirectory,
	    String bcName)
    {
	return
	    baseDirectory +
	    "/trsDB/__" +
	    bcName.replace(':', '_').substring(5, bcName.length()) +
	    "__filepoData";
    }
}
