package COM.ibm.jaws.models.trs;


import java.util.*;
import COM.ibm.jaws.mofw.*;
import COM.ibm.jaws.util.*;


abstract public class FlightBase extends CommonBase
{
    protected static Debug d = new Debug("Flight", true);

    protected Object flightPlan = null;

    protected transient Date departureDateTime = null;
    protected String departureDateTimeString = null;

    protected transient Date arrivalDateTime = null;
    protected String arrivalDateTimeString = null;

    protected Plane plane = null;
    protected int numberSeatsReserved = 0;

    protected ReferenceCollection flightReservationRC = new RCImpl();


    public
    FlightBase()
    {
    }


    public
    FlightBase(Object flightPlan,
	       Date departureDateTime,
	       Date arrivalDateTime)
    {
	this.flightPlan = flightPlan;
	this.departureDateTime = departureDateTime;
	this.arrivalDateTime = arrivalDateTime;
    }


    public void
    activate()
    {
	if (departureDateTime == null && departureDateTimeString != null) {
	    departureDateTime = stringToDate(departureDateTimeString); //new Date(departureDateTimeString);
	}

	if (arrivalDateTime == null && arrivalDateTimeString != null) {
	    arrivalDateTime = stringToDate(arrivalDateTimeString); //new Date(arrivalDateTimeString);
	}
    }


    public void
    cancel(FlightReservation res)
    {
	//@BC
	System.out.println("FlightBase::cancel(FlightReservation res)");
/*
	Iterator flightReservations = null;
	if ((flightReservations =
	     flightReservationRC.evaluate(null, "MOFW::objects")) == null) {
	    return;
	}

	FlightReservation flightReservation = null;
	while ((flightReservation =
		(FlightReservation) flightReservations.getNext()) != null) {

	    if (flightReservation.getConfirmationNumber() ==
		res.getConfirmationNumber()) {

		flightReservationRC.removeElement(flightReservation);
		break;
	    }
	}
*/
	numberSeatsReserved -= res.getNumberTraveling();

	//@BC
	System.out.println("  removing reservation from RC = <<" + res + ">>");
	flightReservationRC.removeElement(res);

    }


    public Date
    getArrivalDateTime()
    {
	return arrivalDateTime;		//@BC
    }


    public Date
    getDepartureDate()
    {
	return new Date(departureDateTime.getYear(),
			departureDateTime.getMonth(),
			departureDateTime.getDate());
    }


    public Date
    getDepartureDateTime()
    {
	return departureDateTime;
    }


    public FlightPlan
    getFlightPlan()
    {
	return (FlightPlan) flightPlan;
    }


    public Plane
    getPlane()
    {
	return plane;
    }


    public int
    getTotalAvailableSeats()
    {
	if (plane == null) {
	    return 0;
	}

	return plane.getTotalSeats() - numberSeatsReserved;
    }


    public int
    getNumberSeatsReserved()
    {
	return numberSeatsReserved;
    }


    public void
    prepareForExternalization()
    {
	if (departureDateTime != null) {
	    departureDateTimeString = dateToString(departureDateTime); //.toGMTString();
	}

	if (arrivalDateTime != null) {
	    arrivalDateTimeString = dateToString(arrivalDateTime); //.toGMTString();
	}
    }


    public void
    reserve(FlightReservation flightReservation)
    {
	flightReservationRC.insertElement(flightReservation);
	numberSeatsReserved += flightReservation.getNumberTraveling();
    }


    public void
    setPlane(String planeString)
    {
	if ((plane = (Plane) planeBC().resolve(planeString)) == null) {
	    throw new RuntimeException();
	}
    }


    public String
    toString()
    {
	return
	    "DepartureDateTime: " + departureDateTime + "\n" +
	    "ArrivalDateTime: " + arrivalDateTime + "\n" +
	    "NumberSeatsReserved: " + numberSeatsReserved + "\n";
    }

    protected Date stringToDate( String date ) {
	Date d = new Date();
	String c = "";
	StringTokenizer st = new StringTokenizer(date, "|");
	c = st.nextToken();
	d.setMonth( Integer.valueOf(c).intValue() );
	c = st.nextToken();
	d.setDate( Integer.valueOf(c).intValue() );
	c = st.nextToken();
	d.setYear( Integer.valueOf(c).intValue() );
	c = st.nextToken();
	d.setHours( Integer.valueOf(c).intValue() );
	c = st.nextToken();
	d.setMinutes( Integer.valueOf(c).intValue() );
	c = st.nextToken();
	d.setSeconds( Integer.valueOf(c).intValue() );
	//System.out.println("stringToDate -> Date = " + date + " converted date = " + d);
	return d;
    }

    protected String dateToString( Date value) {
	String date = Integer.toString( ((Date)value).getMonth() );
	date = date + "|" + Integer.toString( ((Date)value).getDate() );
	date = date + "|" + Integer.toString( ((Date)value).getYear() );
	date = date + "|" + Integer.toString( ((Date)value).getHours() );
	date = date + "|" + Integer.toString( ((Date)value).getMinutes() );
	date = date + "|" + Integer.toString( ((Date)value).getSeconds() );
	//System.out.println("stringToDate -> date String = " + date + " actual date = " + value);
	return date;
    }

}
