package COM.ibm.jaws.models.trs;


import java.util.*;
import java.net.*;
import java.lang.*;

import COM.ibm.jaws.mofw.*;
import COM.ibm.jaws.services.filepobc.*;
import COM.ibm.jaws.services.bcfw.*;
import COM.ibm.jaws.services.sroot.*;
import COM.ibm.jaws.util.*;


public class Populate
{
    static Debug d = null;
    static BaseCollection countryBC = null;
    static BaseCollection stateBC = null;
    static BaseCollection airlineCompanyBC = null;
    static BaseCollection airportBC = null;
    static BaseCollection cityBC = null;
    static BaseCollection flightPlanBC = null;
    static BaseCollection userBC = null;
    static BaseCollection hotelCompanyBC = null;
    static BaseCollection carRentalCompanyBC = null;
    static Random random = null;
    static City austinCityManaged = null;
    static City atlantaCityManaged = null;
    static City bocaRatonCityManaged = null;
    static City chicagoCityManaged = null;
    static City dallasCityManaged = null;
    static City losAngelesCityManaged = null;
    static City newYorkCityManaged = null;
    static BaseCollection srootBC = null;


    public static void
    main(String[] args)
    {
	d = new Debug("Populate", true);

	if (args.length != 1) {
	    System.err.println("Usage: Populate baseDirectory");
	    System.exit(1);
	}


	String baseDirectory = args[0];

	srootBC =
	    SimpleRootBC.getRoot(baseDirectory + "/" +
				 CommonBase.ApplicationSpace);

	BaseCollection applicationRoot =
	    (BaseCollection) srootBC.resolve("trsApplicationRoot");


	countryBC =
	    (BaseCollection) applicationRoot.resolve("countryBC");
	stateBC =
	    (BaseCollection) applicationRoot.resolve("stateBC");
	airlineCompanyBC =
	    (BaseCollection) applicationRoot.resolve("airlineCompanyBC");
	airportBC =
	    (BaseCollection) applicationRoot.resolve("airportBC");
	cityBC =
	    (BaseCollection) applicationRoot.resolve("cityBC");
	flightPlanBC =
	    (BaseCollection) applicationRoot.resolve("flightPlanBC");
	userBC =
	    (BaseCollection) applicationRoot.resolve("userBC");
	hotelCompanyBC =
	    (BaseCollection) applicationRoot.resolve("hotelCompanyBC");
	carRentalCompanyBC =
	    (BaseCollection) applicationRoot.resolve("carRentalCompanyBC");
	random = new Random((long) 2323);


	createCountries();
	createStates();
	createCities();
	createAirports();
 	createAirlineCompanies();
	createCarRentalCompanies();
  	createHotels();
	createUsers();


	d.outln("");
	d.outln("Saving data to the database...");
	srootBC.release();
    }


    public static void
    createCountries()
    {
	//---------------------------------------------------------------------
	// Countries
	d.outln("");
	d.outln("Creating Countries:");


	//---------------------------------------------------------------------
	// USA
	d.outln("    United States of America");
	Country usaCountry = null;
	try {
	    usaCountry =
		new CountryImpl("United States of America",
				"USA",
				new URL("http://www.whitehouse.com"));
	} catch (Throwable e) {
	}

	Country usaCountryManaged = (Country)
	    countryBC.createFromCopy(usaCountry.getName(), usaCountry, null);
    }


    public static void
    createStates()
    {
	//---------------------------------------------------------------------
	// States
	d.outln("");
	d.outln("Creating states:");


	//---------------------------------------------------------------------
	// California
	d.outln("    California");
	State californiaState = null;
	try {
	    californiaState =
		new StateImpl("California",
			      "CA",
			      "United States of America",
			      new URL("http://www.california.com"));
	} catch (Throwable e) {
	}

	State californiaStateManaged = (State)
	    stateBC.createFromCopy(null, californiaState, null);


	//---------------------------------------------------------------------
	// Georgia
	d.outln("    Georgia");
	State georgiaState = null;
	try {
	    georgiaState =
		new StateImpl("Georgia",
			      "GA",
			      "United States of America",
			      new URL("http://www.georgia.com"));
	} catch (Throwable e) {
	}

	State georgiaStateManaged = (State)
	    stateBC.createFromCopy(null, georgiaState, null);


	//---------------------------------------------------------------------
	// Florida
	d.outln("    Florida");
	State floridaState = null;
	try {
	    floridaState =
		new StateImpl("Florida",
			      "FL",
			      "United States of America",
			      new URL("http://www.florida.com"));
	} catch (Throwable e) {
	}

	State floridaStateManaged = (State)
	    stateBC.createFromCopy(null, floridaState, null);


	//---------------------------------------------------------------------
	// Illinois
	d.outln("    Illinois");
	State illinoisState = null;
	try {
	    illinoisState =
		new StateImpl("Illinois",
			      "IL",
			      "United States of America",
			      new URL("http://www.illinois.com"));
	} catch (Throwable e) {
	}

	State illinoisStateManaged = (State)
	    stateBC.createFromCopy(null, illinoisState, null);


	//---------------------------------------------------------------------
	// New York
	d.outln("    New York");
	State newYorkState = null;
	try {
	    newYorkState =
		new StateImpl("New York",
			      "NY",
			      "United States of America",
			      new URL("http://www.newYork.com"));
	} catch (Throwable e) {
	}

	State newYorkStateManaged = (State)
	    stateBC.createFromCopy(null, newYorkState, null);


	//---------------------------------------------------------------------
	// Texas
	d.outln("    Texas");
	State texasState = null;
	try {
	    texasState =
		new StateImpl("Texas",
			      "TX",
			      "United States of America",
			      new URL("http://www.texas.com"));
	} catch (Throwable e) {
	}

	State texasStateManaged = (State)
	    stateBC.createFromCopy(null, texasState, null);
    }


    public static void
    createCities()
    {
	//---------------------------------------------------------------------
	// Cities
	d.outln("");
	d.outln("Creating cities:");


	//---------------------------------------------------------------------
	// Atlanta City
	d.outln("    Atlanta");
	City atlantaCity = null;
	try {
	    atlantaCity =
		new CityImpl("Atlanta",
			     "Georgia",
                             new URL("http://usacitylink.com//atlanta/default.html"),
                             new URL("http://www.usatoday.com/weather/basemaps/nw722190.htm"));
	} catch (Throwable e) {
	}

	atlantaCityManaged = (City)
	    cityBC.createFromCopy(null, atlantaCity, null);


	//---------------------------------------------------------------------
	// Austin City
	d.outln("    Austin");
	City austinCity = null;
	try {
	    austinCity =
		new CityImpl("Austin",
			     "Texas",
                             new URL("http://www.ci.austin.tx.us/"),
                             new URL("http://www.usatoday.com/weather/basemaps/nw722540.htm"));
	} catch (Throwable e) {
	}

	austinCityManaged = (City)
	    cityBC.createFromCopy(null, austinCity, null);


	//---------------------------------------------------------------------
	// Boca Raton City
	d.outln("    Boca Raton");
	City bocaRatonCity = null;
	try {
	    bocaRatonCity =
		new CityImpl("Boca Raton",
			     "Florida",
                             new URL("http://bocaraton.com/"),
                             new URL("http://www.usatoday.com/weather/basemaps/nw722030.htm"));
	} catch (Throwable e) {
	}

	bocaRatonCityManaged = (City)
	    cityBC.createFromCopy(null, bocaRatonCity, null);


	//---------------------------------------------------------------------
	// Chicago City
	d.outln("    Chicago");
	City chicagoCity = null;
	try {
	    chicagoCity =
		new CityImpl("Chicago",
			     "Illinois",
                             new URL("http://http://www.ci.chi.il.us/"),
                             new URL("http://www.usatoday.com/weather/basemaps/nw725300.htm"));
	} catch (Throwable e) {
	}

	chicagoCityManaged = (City)
	    cityBC.createFromCopy(null, chicagoCity, null);


	//---------------------------------------------------------------------
	// Dallas City
	d.outln("    Dallas");
	City dallasCity = null;
	try {
	    dallasCity =
		new CityImpl("Dallas",
			     "Texas",
                             new URL("http://usacitylink.com//dallas/default.html"),
                             new URL("http://www.usatoday.com/weather/basemaps/nw722590.htm"));
	} catch (Throwable e) {
	}

	dallasCityManaged = (City)
	    cityBC.createFromCopy(null, dallasCity, null);


	//---------------------------------------------------------------------
	// Los Angeles City
	d.outln("    Los Angeles");
	City losAngelesCity = null;
	try {
	    losAngelesCity =
		new CityImpl("Los Angeles",
			     "California",
                             new URL("http://www.ci.la.ca.us/"),
                             new URL("http://www.usatoday.com/weather/basemaps/nw722950.htm"));
	} catch (Throwable e) {
	}

	losAngelesCityManaged = (City)
	    cityBC.createFromCopy(null, losAngelesCity, null);


	//---------------------------------------------------------------------
	// New York City
	d.outln("    New York");
	City newYorkCity = null;
	try {
	    newYorkCity =
		new CityImpl("New York",
			     "New York",
                             new URL("http://www.ci.nyc.ny.us/"),
                             new URL("http://www.usatoday.com/weather/basemaps/nw725030.htm"));
	} catch (Throwable e) {
	}

	newYorkCityManaged = (City)
	    cityBC.createFromCopy(null, newYorkCity, null);
    }


    public static void
    createAirports()
    {
	//---------------------------------------------------------------------
	// Airports
	d.outln("");
	d.outln("Creating airports:");


	//---------------------------------------------------------------------
	// Atlanta Airport
	d.outln("    Atlanta");
	Airport atlantaAirport = null;
	try {
	    atlantaAirport =
		new AirportImpl("Atlanta Airport",
				"ATL",
                                new URL("http://www.airnav.com/cgi-bin/airport-info?ATL"));
	} catch (Throwable e) {
	}

	Airport atlantaAirportManaged = (Airport)
	    airportBC.createFromCopy("ATL", atlantaAirport, null);

	atlantaCityManaged.addAirport(atlantaAirportManaged);
	atlantaAirportManaged.addCity(atlantaCityManaged);


	//---------------------------------------------------------------------
	// Austin Airport
	d.outln("    Austin");
	Airport austinAirport = null;
	try {
	    austinAirport =
		new AirportImpl("Austin Airport",
				"AUS",
                                new URL("http://www.ci.austin.tx.us/newairport/"));
	}
	catch (Throwable e) {
	}

	Airport austinAirportManaged = (Airport)
	    airportBC.createFromCopy("AUS", austinAirport, null);

	austinCityManaged.addAirport(austinAirportManaged);
	austinAirportManaged.addCity(austinCityManaged);


	//---------------------------------------------------------------------
	// Boca Raton Airport
	d.outln("    Boca Raton");
	Airport bocaRatonAirport = null;
	try {
	    bocaRatonAirport =
		new AirportImpl("Boca Raton Airport",
                                "BCT",
                                new URL("http://www.airnav.com/cgi-bin/airport-info?BCT"));
	} catch (Throwable e) {
	}

	Airport bocaRatonAirportManaged = (Airport)
            airportBC.createFromCopy("BCT", bocaRatonAirport, null);

	bocaRatonCityManaged.addAirport(bocaRatonAirportManaged);
	bocaRatonAirportManaged.addCity(bocaRatonCityManaged);

	//---------------------------------------------------------------------
	// Chicago Airport
	d.outln("    Chicago");
	Airport chicagoAirport = null;
	try {
	    chicagoAirport =
		new AirportImpl("Chicago Airport",
				"OHR",
                                new URL("http://www.airnav.com/cgi-bin/airport-info?DFW"));
	} catch (Throwable e) {
	}

	Airport chicagoAirportManaged = (Airport)
	    airportBC.createFromCopy("OHR", chicagoAirport, null);

	chicagoCityManaged.addAirport(chicagoAirportManaged);
	chicagoAirportManaged.addCity(chicagoCityManaged);


	//---------------------------------------------------------------------
	// Dallas Airport
	d.outln("    Dallas");
	Airport dallasAirport = null;
	try {
	    dallasAirport =
		new AirportImpl("Dallas Fort-Worth Airport",
				"DFW",
                                new URL("http://www.airnav.com/cgi-bin/airport-info?DFW"));
	} catch (Throwable e) {
	}

	Airport dallasAirportManaged = (Airport)
	    airportBC.createFromCopy("DFW", dallasAirport, null);

	dallasCityManaged.addAirport(dallasAirportManaged);
	dallasAirportManaged.addCity(dallasCityManaged);


	//---------------------------------------------------------------------
	// Los Angelas Airport
	d.outln("    Los Angelas");
	Airport losAngelesAirport = null;
	try {
	    losAngelesAirport =
		new AirportImpl("Los Angeles Airport",
				"LAX",
                                new URL("http://www.quickaid.com/airports/lax/mainmenu.html"));
	} catch (Throwable e) {
	}

	Airport losAngelesAirportManaged = (Airport)
	    airportBC.createFromCopy("LAX", losAngelesAirport, null);

	losAngelesCityManaged.addAirport(losAngelesAirportManaged);
	losAngelesAirportManaged.addCity(losAngelesCityManaged);

	//---------------------------------------------------------------------
	// New York Airport
	d.outln("    Chicago");
	Airport newYorkAirport = null;
	try {
	    newYorkAirport =
		new AirportImpl("New York Airport",
				"LAG",
                                new URL("http://www.airnav.com/cgi-bin/airport-info?DFW"));
	} catch (Throwable e) {
	}

	Airport newYorkAirportManaged = (Airport)
	    airportBC.createFromCopy("LAG", newYorkAirport, null);

	newYorkCityManaged.addAirport(newYorkAirportManaged);
	newYorkAirportManaged.addCity(newYorkCityManaged);

    }


    public static void
    createAirlineCompanies()
    {
	//---------------------------------------------------------------------
	// Airline Comanies
	d.outln("");
	d.outln("Creating Airline Companies:");

	//---------------------------------------------------------------------
	// American Airlines
	d.outln("");
	d.outln("    American Airlines.");
	AirlineCompany americanAirlines =
	    new AirlineCompanyImpl("American Airlines");

	AirlineCompany americanAirlinesManaged = (AirlineCompany)
	    airlineCompanyBC.createFromCopy(null, americanAirlines, null);

	americanAirlinesManaged.addContact("",
					   "",
					   "Dallas",
					   "77777",
					   "800",
					   "433-7300",
					   "",
					   "",
					   "",
					   "",
					   (URL) null);
	Plane DC9 =
	    americanAirlinesManaged.addPlane("DC-9",
					     "images/dc9_pln.gif",
					     "",
					     200);
	Plane DC10 =
	    americanAirlinesManaged.addPlane("DC-10",
					     "images/dc10_pln.gif",
					     "",
					     220);

	//--------
	// Austin to Atlanta
	d.outln("        Flight plan: 100");
	FlightPlan aaAustinToAtlanta =
	    americanAirlinesManaged.addFlightPlan("100",
						  "AUS",
						  "ATL",
						  210);

	for (int day = 1; day < 8; day++) {

	    if ((day % 2) == 0) {
		aaAustinToAtlanta.addFlight(new Date(97, 0,
						     day, 8, 00),
					    new Date(97, 0,
						     day, 12, 00),
					    DC9.getName());
		aaAustinToAtlanta.addFlight(new Date(97, 0,
						     day, 10, 00),
					    new Date(97, 0,
						     day, 14, 00),
					    DC10.getName());
		aaAustinToAtlanta.addFlight(new Date(97, 0,
						     day, 17, 00),
					    new Date(97, 0,
						     day, 21, 00),
					    DC9.getName());
		aaAustinToAtlanta.addFlight(new Date(97, 0,
						     day, 19, 00),
					    new Date(97, 0,
						     day, 23, 00),
					    DC10.getName());
	    }
	    else {
		aaAustinToAtlanta.addFlight(new Date(97, 0,
						     day, 9, 00),
					    new Date(97, 0,
						     day, 13, 00),
					    DC9.getName());
		aaAustinToAtlanta.addFlight(new Date(97, 0,
						     day, 11, 00),
					    new Date(97, 0,
						     day, 15, 00),
					    DC10.getName());
		aaAustinToAtlanta.addFlight(new Date(97, 0,
						     day, 18, 00),
					    new Date(97, 0,
						     day, 22, 00),
					    DC9.getName());
		aaAustinToAtlanta.addFlight(new Date(97, 0,
						     day, 20, 00),
					    new Date(97, 0,
						     day, 24, 00),
					    DC10.getName());
	    }
	}


	//--------
	// Atlanta to Austin
	d.outln("        Flight plan: 101");
	FlightPlan aaAtlantaToAustin =
	    americanAirlinesManaged.addFlightPlan("101",
						  "ATL",
						  "AUS",
						  210);

	for (int day = 1; day < 8; day++) {

	    if ((day % 2) == 0) {
		aaAtlantaToAustin.addFlight(new Date(97, 0,
						     day, 8, 00),
					    new Date(97, 0,
						     day, 12, 00),
					    DC9.getName());
		aaAtlantaToAustin.addFlight(new Date(97, 0,
						     day, 10, 00),
					    new Date(97, 0,
						     day, 14, 00),
					    DC9.getName());
		aaAtlantaToAustin.addFlight(new Date(97, 0,
						     day, 17, 00),
					    new Date(97, 0,
						     day, 21, 00),
					    DC9.getName());
		aaAtlantaToAustin.addFlight(new Date(97, 0,
						     day, 19, 00),
					    new Date(97, 0,
						     day, 23, 00),
					    DC9.getName());
	    }
	    else {
		aaAtlantaToAustin.addFlight(new Date(97, 0,
						     day, 9, 00),
					    new Date(97, 0,
						     day, 13, 00),
					    DC9.getName());
		aaAtlantaToAustin.addFlight(new Date(97, 0,
						     day, 11, 00),
					    new Date(97, 0,
						     day, 15, 00),
					    DC9.getName());
		aaAtlantaToAustin.addFlight(new Date(97, 0,
						     day, 18, 00),
					    new Date(97, 0,
						     day, 22, 00),
					    DC9.getName());
		aaAtlantaToAustin.addFlight(new Date(97, 0,
						     day, 20, 00),
					    new Date(97, 0,
						     day, 24, 00),
					    DC9.getName());
	    }
	}


	//---------------------------------------------------------------------
	// Continental Airlines
	d.outln("");
	d.outln("    Continental Airlines");
	AirlineCompany continentalAirlines =
	    new AirlineCompanyImpl("Continental Airlines");
	AirlineCompany continentalAirlinesManaged = (AirlineCompany)
	    airlineCompanyBC.createFromCopy(null, continentalAirlines, null);

	continentalAirlinesManaged.addContact("",
					      "",
					      "Dallas",
					      "71111",
					      "800",
					      "111-2222",
					      "",
					      "",
					      "",
					      "",
					      (URL) null);

	Plane boeing727 =
	    continentalAirlinesManaged.addPlane("B727",
					      	"images/727_pln.gif",
					      	"", 240);
	Plane boeing747 =
	    continentalAirlinesManaged.addPlane("B747",
					      	"images/747_pln.gif",
						"", 411);
	Plane boeing757 =
	    continentalAirlinesManaged.addPlane("B757",
					      	"images/757_pln.gif",
						"", 390);


	d.outln("        Flight plan: 500");
	FlightPlan caAustinToAtlanta =
	    continentalAirlinesManaged.addFlightPlan("500",
						     "AUS",
						     "ATL",
						     225);

	for (int day = 1; day < 8; day++) {
	    caAustinToAtlanta.addFlight(new Date(97, 0,
						 day, 6, 30),
					new Date(97, 0,
						 day, 10, 30),
					boeing727.getName());
	    caAustinToAtlanta.addFlight(new Date(97, 0,
						 day, 9, 30),
					new Date(97, 0,
						 day, 12, 30),
					boeing727.getName());
	    caAustinToAtlanta.addFlight(new Date(97, 0,
						 day, 12, 30),
					new Date(97, 0,
						 day, 16, 30),
					boeing727.getName());
	    caAustinToAtlanta.addFlight(new Date(97, 0,
						 day, 16, 30),
					new Date(97, 0,
						 day, 20, 30),
					boeing727.getName());
	    caAustinToAtlanta.addFlight(new Date(97, 0,
						 day, 16, 30),
					new Date(97, 0,
						 day, 22, 30),
					boeing727.getName());
	}


	d.outln("        Flight plan: 501");
	FlightPlan caAtlantaToAustin =
	    continentalAirlinesManaged.addFlightPlan("501",
						     "ATL",
						     "AUS",
						     318);

 	for (int day = 1; day < 8; day++) {
	    caAtlantaToAustin.addFlight(new Date(97, 0,
						 day, 8, 0),
					new Date(97, 0,
						 day, 12, 0),
					boeing747.getName());
	    caAtlantaToAustin.addFlight(new Date(97, 0,
						 day, 10, 0),
					new Date(97, 0,
						 day, 14, 0),
					boeing757.getName());
	    caAtlantaToAustin.addFlight(new Date(97, 0,
						 day, 12, 30),
					new Date(97, 0,
						 day, 16, 30),
					boeing747.getName());
	    caAtlantaToAustin.addFlight(new Date(97, 0,
						 day, 16, 0),
					new Date(97, 0,
						 day, 20, 0),
					boeing757.getName());
	    caAtlantaToAustin.addFlight(new Date(97, 0,
						 day, 18, 30),
					new Date(97, 0,
						 day, 22, 30),
					boeing747.getName());
	}
    }


    public static void
    createCarRentalCompanies()
    {
	//---------------------------------------------------------------------
	// Car Rental Companies
	d.outln("");
	d.outln("Creating Car Rental Companies:");


	//---------------------------------------------------------------------
	// Hertz Car Rental
	d.outln("");
	d.outln("    Hertz");
	CarRentalCompany hertz =
	    new CarRentalCompanyImpl("Hertz");

	CarRentalCompany hertzManaged = (CarRentalCompany)
	    carRentalCompanyBC.createFromCopy(null, hertz, null);

	try {
	    hertzManaged.addContact("",
				    "",
				    "New York",
				    "22222",
				    "800",
				    "xxx-yyyy",
				    "",
				    "",
				    "",
				    "",
				    new URL("http://www.hertz.com"));
	} catch (Throwable e) {
	}

	String[] hertzCar = {
	    "Ford Aspire",
	    "Ford Escort",
	    "Ford Contour",
	    "Ford Thunderbird",
	    "Ford Taurus",
	    "Ford Crown Victoria",
	    "Ford Lincoln Town Car",
	    "Ford Explorer",
	    "Ford Windstar",
	    "Ford Mustang" };
	int totalCars = hertzCar.length;

	String[] hertzFleetType = {
	    "Economy",
	    "Compact 4-door",
	    "Mid-size",
	    "Full-Size 2-door",
	    "Full-Size 4-door",
	    "Premium",
	    "Luxury",
	    "4WD Truck",
	    "Mini Van",
	    "Convertible" };

	String[] hertzLocation = {
	    "AUS",
// 	    "LAX",
// 	    "BR",
	    "ATL",
// 	    "DFW"
	};
	int totalLocations = hertzLocation.length;

	for (int carIndex = 0;
	     carIndex < totalCars;
	     carIndex++) {

	    hertzManaged.addCar(hertzCar[carIndex], "images/car.gif");
	}


	// For each hertz location (airport code) in the country, add the
	// fleet of cars to that location and an availability of each fleet.
	for (int locationIndex = 0;
	     locationIndex < totalLocations;
	     locationIndex++) {

	    d.outln("        Creating fleets in: " +
		    hertzLocation[locationIndex]);
	    for (int fleetCarIndex = 0;
		 fleetCarIndex < totalCars;
		 fleetCarIndex++) {

		d.outln("            " +
			hertzFleetType[fleetCarIndex]);
		CarFleet hertzFleet =
		    hertzManaged.addCarFleet(hertzLocation[locationIndex],
					     hertzFleetType[fleetCarIndex],
					     fleetCarIndex + 38,
					     hertzCar[fleetCarIndex]);

		for (int dayOfYear = 1; dayOfYear < 8; dayOfYear++) {
		    hertzFleet.addCarFleetAvailability
			(new Date(97, 0, dayOfYear),
			 (Math.abs(random.nextInt() % 15 + 2)));
		}
	    }
	}


	//---------------------------------------------------------------------
	// Avis Car Rental
	d.outln("");
	d.outln("    AVIS");
	CarRentalCompany avis =
	    new CarRentalCompanyImpl("AVIS");

	CarRentalCompany avisManaged = (CarRentalCompany)
	    carRentalCompanyBC.createFromCopy(null, avis, null);

	try {
	    avisManaged.addContact("",
				   "",
				   "New York",
				   "22222",
				   "800",
				   "xxx-yyyy",
				   "",
				   "",
				   "",
				   "",
				   new URL("http://www.avis.com"));
	} catch (Throwable e) {
	    e.printStackTrace();
	}

	String[] avisCar = {
	    "Chevrolet Geo Metro",
	    "Chevrolet Cavalier",
	    "Chevrolet Monte Carlo",
	    "Pontiac Bonneville",
	    "Chevrolet Cavalier Convertible",
	    "Pontiac Grand Am",
	    "Buick Regal",
	    "Cadillac Sedan de Ville",
	    "Chevrolet Blazer",
	    "Pontiac Trans Sport",
	    "Oldsmobile Eighty-Eight",
	    "Pontiac Sunfire"
	};
	totalCars = avisCar.length;

// 	String[] avisFleetType = {
// 	    "4 Door Subcompact",
// 	    "4 Door Compact",
// 	    "2 Door Full Size",
// 	    "Premium",
// 	    "Convertible",
// 	    "Satellite Guidance System Vehicle",
// 	    "2 Door Compact",
// 	    "Intermediate",
// 	    "4 Door Full Size",
// 	    "Luxury",
// 	    "4 Wheel Drive",
// 	    "Mini-Van" };

	String[] avisFleetType = {
	    "Economy",
	    "Compact 4-door",
	    "Full-Size 2-door",
	    "Premium",
	    "Convertible",
	    "Mid-size",
	    "Full-Size 4-door",
	    "Luxury",
	    "4WD Truck",
	    "Mini Van",
	    "Satellite Guidance System Vehicle",
	    "2 Door Compact"
 	};

	String[] avisLocation = {
	    "AUS",
// 	    "LAX",
// 	    "BR",
	    "ATL",
// 	    "DFW"
	};
	totalLocations = avisLocation.length;

	for (int carIndex = 0;
	     carIndex < totalCars;
	     carIndex++) {

	    avisManaged.addCar(avisCar[carIndex], "images/car.gif");
	}

	for (int locationIndex = 0;
	     locationIndex < totalLocations;
	     locationIndex++) {

	    d.outln("        Creating fleet in: " +
		    avisLocation[locationIndex]);

	    for (int fleetCarIndex = 0;
		 fleetCarIndex < totalCars;
		 fleetCarIndex++) {

		d.outln("            " + avisFleetType[fleetCarIndex]);

		CarFleet avisFleet =
		    avisManaged.addCarFleet(avisLocation[locationIndex],
					    avisFleetType[fleetCarIndex],
					    fleetCarIndex + 30,
					    avisCar[fleetCarIndex]);

		for (int dayOfYear = 1; dayOfYear < 8; dayOfYear++) {
		    avisFleet.addCarFleetAvailability
			(new Date(97, 0, dayOfYear),
			 (Math.abs(random.nextInt() % 15 + 2)));
		}
	    }
	}
    }


    public static void
    createHotels()
    {
	//---------------------------------------------------------------------
	// Hotel Companies
	d.outln("");
	d.outln("Creating Hotel Companies:");


	//---------------------------------------------------------------------
	// Hyatt
	String[] hyattRoomGroupType = {
	    "Double Double",
	    "Queen King",
	    "Suite" };
	int totalGroups = hyattRoomGroupType.length;

	String[] hyattLocation = {
	    "Austin",
// 	    "Los Angeles",
// 	    "Boca Raton",
	    "Atlanta",
// 	    "Dallas"
	};
	int totalLocations = hyattLocation.length;


	d.outln("");
	d.outln("    Hyatt Regency");
	HotelCompany hyatt =
	    new HotelCompanyImpl("Hyatt Regency",
				 "");

	HotelCompany hyattManaged = (HotelCompany)
	    hotelCompanyBC.createFromCopy(null, hyatt, null);

	try {
	    hyattManaged.addContact
		("",
		 "",
		 "Chicago",
		 "88991",
		 "800",
		 "xxx-yyyy",
		 "",
		 "",
		 "",
		 "",
		 new URL("http://www.hyatt.com"));
	} catch (Throwable e) {
	}

	for (int locationIndex = 0;
	     locationIndex < totalLocations;
	     locationIndex++) {

	    d.outln("        Creating room groups in: " +
		    hyattLocation[locationIndex]);

	    for (int roomGroupIndex = 0;
		 roomGroupIndex < totalGroups;
		 roomGroupIndex++) {

		d.outln("            " +
			hyattRoomGroupType[roomGroupIndex]);

		RoomGroup hyattRoomGroup =
		    hyattManaged.addRoomGroup
		    (hyattLocation[locationIndex],
		     hyattRoomGroupType[roomGroupIndex],
		     "Information about the room goes here.",
		     roomGroupIndex + 110);

		hyattRoomGroup.addLocationInformation
		    (hyattLocation[locationIndex],
		     "991 Research Drive",
		     "",
		     hyattLocation[locationIndex],
		     "77665",
		     "512",
		     "888-9999",
		     "",
		     "",
		     "",
		     "",
		     null);

		for (int dayOfYear = 1; dayOfYear < 8; dayOfYear++) {
		    hyattRoomGroup.addRoomGroupAvailability
			(new Date(97, 0, dayOfYear),
			 (Math.abs(random.nextInt() % 400 + 100)));
		}
	    }
	}


	//---------------------------------------------------------------------
	// Holiday Inn
	String[] holidayInnRoomGroupType = {
	    "Double Double",
	    "Queen King",
	    "Suite" };
	totalGroups = holidayInnRoomGroupType.length;

	String[] holidayInnLocation = {
	    "Austin",
// 	    "Los Angeles",
// 	    "Boca Raton",
	    "Atlanta",
// 	    "Dallas"
	};
	totalLocations = holidayInnLocation.length;


	d.outln("");
	d.outln("    Holiday Inn");
	HotelCompany holidayInn =
	    new HotelCompanyImpl("Holiday Inn",
				 "");

	HotelCompany holidayInnManaged = (HotelCompany)
	    hotelCompanyBC.createFromCopy(null, holidayInn, null);

	holidayInnManaged.addContact("",
				     "",
				     "Austin",
				     "78787",
				     "800",
				     "xxx-yyyy",
				     "",
				     "",
				     "",
				     "",
				     (URL) null);

	for (int locationIndex = 0;
	     locationIndex < totalLocations;
	     locationIndex++) {

	    d.outln("        Creating room groups in: " +
		    holidayInnLocation[locationIndex]);

	    for (int roomGroupIndex = 0;
		 roomGroupIndex < totalGroups;
		 roomGroupIndex++) {

		d.outln("            " +
			holidayInnRoomGroupType[roomGroupIndex]);

		RoomGroup holidayInnRoomGroup =
		    holidayInnManaged.addRoomGroup
		    (holidayInnLocation[locationIndex],
		     holidayInnRoomGroupType[roomGroupIndex],
		     "Information about the room goes here.",
		     roomGroupIndex + 85);

		holidayInnRoomGroup.addLocationInformation
		    (holidayInnLocation[locationIndex],
		     "991 Research Drive",
		     "",
		     holidayInnLocation[locationIndex],
		     "77665",
		     "512",
		     "888-9999",
		     "",
		     "",
		     "",
		     "",
		     null);


		for (int dayOfYear = 1; dayOfYear < 8; dayOfYear++) {
		    holidayInnRoomGroup.addRoomGroupAvailability
			(new Date(97, 0, dayOfYear),
			 (Math.abs(random.nextInt() % 400 + 100)));
		}
	    }
	}


	//---------------------------------------------------------------------
	// Ramada
	String[] ramadaRoomGroupType = {
	    "Double Double",
	    "Queen King",
	    "Suite" };
	totalGroups = ramadaRoomGroupType.length;

	String[] ramadaLocation = {
	    "Austin",
// 	    "Los Angeles",
// 	    "Boca Raton",
	    "Atlanta",
// 	    "Dallas"
	};
	totalLocations = ramadaLocation.length;


	d.outln("");
	d.outln("     Ramada");
	HotelCompany ramada =
	    new HotelCompanyImpl("Ramada",
				 "");

	HotelCompany ramadaManaged = (HotelCompany)
	    hotelCompanyBC.createFromCopy(null, ramada, null);

	try {
	    ramadaManaged.addContact
		("",
		 "",
		 "New York",
		 "78787",
		 "800",
		 "xxx-yyyy",
		 "",
		 "",
		 "",
		 "",
		 new URL("http://www.ramada.com"));
	} catch (Throwable e) {
	}

	for (int locationIndex = 0;
	     locationIndex < totalLocations;
	     locationIndex++) {

	    d.outln("        Creating room groups in: " +
		    ramadaLocation[locationIndex]);

	    for (int roomGroupIndex = 0;
		 roomGroupIndex < totalGroups;
		 roomGroupIndex++) {

		d.outln("            " +
			ramadaRoomGroupType[roomGroupIndex]);

		RoomGroup ramadaRoomGroup =
		    ramadaManaged.addRoomGroup
		    (ramadaLocation[locationIndex],
		     ramadaRoomGroupType[roomGroupIndex],
		     "Information about the room goes here.",
		     roomGroupIndex + 110);

		ramadaRoomGroup.addLocationInformation
		    (ramadaLocation[locationIndex],
		     "991 Research Drive",
		     "",
		     ramadaLocation[locationIndex],
		     "77665",
		     "512",
		     "888-9999",
		     "",
		     "",
		     "",
		     "",
		     null);

		for (int dayOfYear = 1; dayOfYear < 8; dayOfYear++) {
		    ramadaRoomGroup.addRoomGroupAvailability
			(new Date(97, 0, dayOfYear),
			 (Math.abs(random.nextInt() % 400 + 100)));
		}
	    }
	}
    }


    public static void
    createUsers()
    {
	Trip trip = null;
	CarFleet car = null;
	RoomGroup room = null;
	Flight flight = null;

	//---------------------------------------------------------------------
	// Users
	d.outln("");
	d.outln("Creating Users:");


	//---------------------------------------------------------------------
	// User Shane Claussen
	d.outln("");
	d.outln("    Shane Claussen");
	User userManageable = new UserImpl("Claussen",
					   "Shane",
					   "",
					   "Mr.",
					   "shane",
					   "shane",
					   "444-44-4444",
					   new Date(77, 8, 27),
					   "14698413",
					   "TX");
	User userManaged =
	    (User) userBC.createFromCopy(userManageable.getUserId(),
					 userManageable,
					 null);

	d.outln("        Creating home contact");
	userManaged.addHomeContact("3808 Latimer Drive",
				   "",
				   "Austin",
				   "78732",
				   "512",
				   "266-8678",
				   "",
				   "",
				   "",
				   "",
				   (URL) null);

	try {
	    d.outln("        Creating employer contact");
	    userManaged.addEmployerInformation("IBM",
					       "11400 Burnet Road",
					       "",
					       "Austin",
					       "78756",
					       "512",
					       "838-3276",
					       "512",
					       "838-2202",
					       "shane",
					       "austin.ibm.com",
					       new URL("http://www.ibm.com"));
	} catch (Throwable e) {
	}


	d.outln("        Creating travel profile");
	TravelProfile travelProfile = userManaged.addTravelProfile();

	d.outln("        Creating credit cards:");
	d.outln("            Visa");
	CreditCard cc = travelProfile.addCreditCard("Visa",
						    "111-2222-333",
						    new Date(97, 11, 11));
	d.outln("            American Express");
	travelProfile.addCreditCard("American Express",
				    "999-8888-777",
				    new Date(97, 10, 10));

	d.outln("        Setting preferred credit card");
	travelProfile.setPreferredCreditCard(cc);


	d.outln("        Creating trips:");
	d.outln("            Olympics WWW Consulting");
	trip = userManaged.addTrip("Olympics WWW Consulting",
			    austinCityManaged.getName(),
			    atlantaCityManaged.getName(),
			    new Date(97, 0, 1),
			    new Date(97, 0, 7));

	car = (CarFleet) srootBC.resolve("trsApplicationRoot/carFleetBC/13");
    	trip.reserveCar(car, 1);
	room = (RoomGroup) srootBC.resolve("trsApplicationRoot/roomGroupBC/5");
    	trip.reserveHotel(room, 1);
	flight = (Flight) srootBC.resolve("trsApplicationRoot/flightBC/3");
    	trip.reserveDepartureFlight(flight, 1, "10A");
        flight = (Flight) srootBC.resolve("trsApplicationRoot/flightBC/54");
    	trip.reserveReturnFlight(flight, 1, "20A");

	d.outln("            Raleigh Dev/2000");
	trip = userManaged.addTrip("Raleigh Dev/2000",
                            austinCityManaged.getName(),
                            atlantaCityManaged.getName(),
			    new Date(97, 0, 3),
			    new Date(97, 0, 5));

	car = (CarFleet) srootBC.resolve("trsApplicationRoot/carFleetBC/13");
    	trip.reserveCar(car, 1);
	room = (RoomGroup) srootBC.resolve("trsApplicationRoot/roomGroupBC/5");
    	trip.reserveHotel(room, 1);
	flight = (Flight) srootBC.resolve("trsApplicationRoot/flightBC/10");
    	trip.reserveDepartureFlight(flight, 1, "10A");
	flight = (Flight) srootBC.resolve("trsApplicationRoot/flightBC/46");
    	trip.reserveReturnFlight(flight, 1, "12A");
	trip.confirm(null);

	//---------------------------------------------------------------------
	// Bryce Curtis
	d.outln("");
	d.outln("    Bryce Curtis");
	userManageable = new UserImpl("Curtis",
				      "Bryce",
				      "A",
				      "Dr.",
				      "bcurtis",
				      "bcurtis",
				      "111-22-3333",
				      new Date(77, 8, 27),
				      "22446688",
				      "TX");
	userManaged = (User) userBC.createFromCopy(userManageable.getUserId(),
						   userManageable,
						   null);
	d.outln("        Creating home contact");
	userManaged.addHomeContact("4105 Vista Isle Dr.",
				   "",
				   "Austin",
				   "78681",
				   "512",
				   "255-9242",
				   "",
				   "",
				   "",
				   "",
				   (URL) null);
	try {
	    d.outln("        Creating employer contact");
	    userManaged.addEmployerInformation("IBM",
					       "11400 Burnet",
					       "",
					       "Austin",
					       "78756",
					       "512",
					       "838-1064",
					       "512",
					       "838-2202",
					       "bcurtis",
					       "austin.ibm.com",
					       new URL("http://www.ibm.com"));
	} catch (Throwable e) {
	}


	d.outln("        Creating travel profile");
	travelProfile = userManaged.addTravelProfile();

	d.outln("        Creating credit cards:");

	d.outln("            Visa");
	travelProfile.addCreditCard("Visa",
				    "222-3333-4444",
				    new Date(97, 11, 11));

	d.outln("            American Express");
	travelProfile.addCreditCard("American Express",
				    "666-5555-4444",
				    new Date(97, 11, 11));

	d.outln("        Creating trips:");
	d.outln("            Olympics WWW Consulting");
	trip = userManaged.addTrip("Olympics WWW Consulting",
			    austinCityManaged.getName(),
			    atlantaCityManaged.getName(),
			    new Date(97, 0, 1),
			    new Date(97, 0, 7));

	car = (CarFleet) srootBC.resolve("trsApplicationRoot/carFleetBC/13");
    	trip.reserveCar(car, 1);
	room = (RoomGroup) srootBC.resolve("trsApplicationRoot/roomGroupBC/5");
    	trip.reserveHotel(room, 1);
	flight = (Flight) srootBC.resolve("trsApplicationRoot/flightBC/3");
    	trip.reserveDepartureFlight(flight, 1, "1A");
        flight = (Flight) srootBC.resolve("trsApplicationRoot/flightBC/54");
    	trip.reserveReturnFlight(flight, 1, "2A");

	d.outln("            Raleigh Dev/2000");
	trip = userManaged.addTrip("Raleigh Dev/2000",
                            austinCityManaged.getName(),
                            atlantaCityManaged.getName(),
			    new Date(97, 0, 3),
			    new Date(97, 0, 5));

	car = (CarFleet) srootBC.resolve("trsApplicationRoot/carFleetBC/13");
    	trip.reserveCar(car, 1);
	room = (RoomGroup) srootBC.resolve("trsApplicationRoot/roomGroupBC/5");
    	trip.reserveHotel(room, 1);
	flight = (Flight) srootBC.resolve("trsApplicationRoot/flightBC/10");
    	trip.reserveDepartureFlight(flight, 1, "1A");
	flight = (Flight) srootBC.resolve("trsApplicationRoot/flightBC/46");
    	trip.reserveReturnFlight(flight, 1, "2A");
	trip.confirm(null);

	d.outln("            IEEE Conference");
	trip = userManaged.addTrip("IEEE Conference",
                            austinCityManaged.getName(),
                            atlantaCityManaged.getName(),
			    new Date(97, 0, 1),
			    new Date(97, 0, 3));

	car = (CarFleet) srootBC.resolve("trsApplicationRoot/carFleetBC/13");
    	trip.reserveCar(car, 1);
	room = (RoomGroup) srootBC.resolve("trsApplicationRoot/roomGroupBC/5");
    	trip.reserveHotel(room, 1);
        flight = (Flight) srootBC.resolve("trsApplicationRoot/flightBC/2");
    	trip.reserveDepartureFlight(flight, 1, "1A");
        flight = (Flight) srootBC.resolve("trsApplicationRoot/flightBC/38");
    	trip.reserveReturnFlight(flight, 1, "2A");
	trip.taken();


	//---------------------------------------------------------------------
	// Unknown
	d.outln("");
	d.outln("    Unknown");
	userManageable = new UserImpl("Unknown",
				      "",
				      "",
				      "",
				      "Unknown",
				      "Unknown",
				      "",
				      new Date(),
				      "",
				      "");
	userManaged = (User) userBC.createFromCopy(userManageable.getUserId(),
						   userManageable,
						   null);
	d.outln("        Creating home contact");
	userManaged.addHomeContact("",
				   "",
				   "",
				   "",
				   "",
				   "",
				   "",
				   "",
				   "",
				   "",
				   (URL) null);
	try {
	    d.outln("        Creating employer contact");
	    userManaged.addEmployerInformation("",
					       "",
					       "",
					       "",
					       "",
					       "",
					       "",
					       "",
					       "",
					       "",
					       "",
					       null);
	} catch (Throwable e) {
	}

	d.outln("        Creating travel profile");
	travelProfile = userManaged.addTravelProfile();

    }
}
