package COM.ibm.jaws.models.trs;


import COM.ibm.jaws.mofw.*;
import COM.ibm.jaws.util.*;
import java.util.*;
import java.net.*;


abstract public class RoomGroupBase extends CommonBase
{
    protected static Debug d = new Debug("RoomGroup", true);

    protected Object hotelCompany = null;

    protected City city = null;
    protected String cityString = null;

    protected String location = null;
    protected Contact contact = null;

    protected String info = null;
    protected String name = null;
    protected float price = (float) 0;
    protected ReferenceCollection roomGroupAvailabilityRC = null;
    protected ReferenceCollection hotelReservationRC = new RCImpl();


    public
    RoomGroupBase()
    {
    }


    public
    RoomGroupBase(Object hotelCompany,
		  String cityString,
		  String name,
		  String info,
		  float price)
    {
	this.hotelCompany = hotelCompany;
	this.cityString = cityString;
	this.name = name;
	this.info = null;
	this.price = price;
    }


    public void
    activate()
    {
	if (cityString != null) {
	    setCity(cityString);
	    cityString = null;
	}
    }


    public Contact
    addLocationInformation(String location,
			   String address1,
			   String address2,
			   String cityString,
			   String zip,
			   String phoneAreaCode,
			   String phoneNumber,
			   String faxAreaCode,
			   String faxNumber,
			   String emailId,
			   String emailAddress,
			   URL url)
    {
	this.location = location;

	Contact contactManageable =
	    new ContactImpl(self, address1, address2,
			    cityString, zip,
			    phoneAreaCode, phoneNumber,
			    faxAreaCode, faxNumber,
			    emailId, emailAddress, url);

	contact =
	    (Contact) contactBC().createFromCopy(null,
						 contactManageable,
						 null);

	return contact;
    }


    public RoomGroupAvailability
    addRoomGroupAvailability(Date date,
			     int totalAvailableRooms)
    {
	if (roomGroupAvailabilityRC == null) {
	    roomGroupAvailabilityRC = (ReferenceCollection)
		roomGroupRoomGroupAvailabilityRCBC().createFromCopy(null,
								    null,
								    null);
	}

	RoomGroupAvailability roomGroupAvailability =
	    new RoomGroupAvailabilityImpl(this,
					  date,
					  totalAvailableRooms);

	RoomGroupAvailability roomGroupAvailabilityManaged =
	    (RoomGroupAvailability)
	    roomGroupAvailabilityBC().createFromCopy(null,
						     roomGroupAvailability,
						     null);

	roomGroupAvailabilityRC.insertElement(roomGroupAvailabilityManaged);

	return roomGroupAvailabilityManaged;
    }


    public boolean
    available(Date startDate,
	      Date endDate)
    {
	int startYear = startDate.getYear();
	int startMonth = startDate.getMonth();
	int startDay = startDate.getDate();

	Date date = new Date(startYear, startMonth, startDay);
	while (date.before(endDate) || date.equals(endDate)) {
	    if (roomGroupAvailabilityAvailable(date) == false) {
		return false;
	    }
	    date = new Date(startYear, startMonth, ++startDay);
	}

	return true;
    }


    public void
    cancel(HotelReservation res)
    {
	//@BC
	System.out.println("RoomGroupBase::cancel(HotelReservation res)");
/*
	Iterator hotelReservations = null;
	if ((hotelReservations =
	     hotelReservationRC.evaluate(null, "MOFW::objects")) == null) {
	    return;
	}

	HotelReservation hotelReservation = null;
	while ((hotelReservation =
		(HotelReservation) hotelReservations.getNext()) != null) {

	    if (hotelReservation.getConfirmationNumber() ==
		res.getConfirmationNumber()) {

		hotelReservationRC.removeElement(hotelReservation);
		break;
	    }
	}
*/

	Date arrivalDate = res.getTrip().getDepartureDate();
	Date departureDate = res.getTrip().getReturnDate();

	int arrivalYear = arrivalDate.getYear();
	int arrivalMonth = arrivalDate.getMonth();
	int arrivalDay = arrivalDate.getDate();

	Date date = new Date(arrivalYear, arrivalMonth, arrivalDay);
	while (date.before(departureDate) || date.equals(departureDate)) {
	    roomGroupAvailbilityCancel(date);
	    date = new Date(arrivalYear, arrivalMonth, ++arrivalDay);
	}

	//@BC
	System.out.println("  removing reservation from RC = <<" + res + ">>");
	hotelReservationRC.removeElement(res);
//@BCBC
//System.out.println("  Actually removing reservation from BC!!!!");
//	res.remove();
    }


    public City
    getCity()
    {
	return city;
    }


    public Contact
    getContact()
    {
	return contact;
    }


    public HotelCompany
    getHotelCompany()
    {
	return (HotelCompany) hotelCompany;
    }


    public String
    getInfo()
    {
	return info;
    }


    public String
    getLocation()
    {
	return location;
    }


    public String
    getName()
    {
	return name;
    }


    public float
    getPrice()
    {
	return price;
    }


    public Iterator
    getRoomGroupAvailabilities()
    {
	return roomGroupAvailabilityRC.evaluate(null, "MOFW::objects");
    }


    public void
    reserve(HotelReservation hotelReservation)
    {
	hotelReservationRC.insertElement(hotelReservation);

	Date arrivalDate = hotelReservation.getTrip().getDepartureDate();
	Date departureDate = hotelReservation.getTrip().getReturnDate();

	int arrivalYear = arrivalDate.getYear();
	int arrivalMonth = arrivalDate.getMonth();
	int arrivalDay = arrivalDate.getDate();

	Date date = new Date(arrivalYear, arrivalMonth, arrivalDay);
	while (date.before(departureDate) || date.equals(departureDate)) {
	    roomGroupAvailabilityReserve(date);
	    date = new Date(arrivalYear, arrivalMonth, ++arrivalDay);
	}
    }


    public void
    roomGroupAvailbilityCancel(Date date)
    {
	Iterator roomGroupAvailabilities = null;
	if ((roomGroupAvailabilities = getRoomGroupAvailabilities()) == null) {
	    return;
	}

	RoomGroupAvailability roomGroupAvailability = null;
	while ((roomGroupAvailability = (RoomGroupAvailability)
		roomGroupAvailabilities.getNext()) != null) {

	    if (roomGroupAvailability.getDate().equals(date)) {
		roomGroupAvailability.cancel();
		return;
	    }
	}
    }


    protected void
    roomGroupAvailabilityReserve(Date date)
    {
	Iterator roomGroupAvailabilities = null;
	if ((roomGroupAvailabilities = getRoomGroupAvailabilities()) == null) {
	    return;
	}

	RoomGroupAvailability roomGroupAvailability = null;
	while ((roomGroupAvailability = (RoomGroupAvailability)
		roomGroupAvailabilities.getNext()) != null) {

	    if (roomGroupAvailability.getDate().equals(date)) {
		roomGroupAvailability.reserve();
		break;
	    }
	}
    }


    protected boolean
    roomGroupAvailabilityAvailable(Date date)
    {
	Iterator roomGroupAvailabilities = null;
	if ((roomGroupAvailabilities = getRoomGroupAvailabilities()) == null) {
	    return false;
	}

	RoomGroupAvailability roomGroupAvailability = null;
	while ((roomGroupAvailability = (RoomGroupAvailability)
		roomGroupAvailabilities.getNext()) != null) {

	    if (roomGroupAvailability.getDate().equals(date) &&
		roomGroupAvailability.getTotalAvailableRooms() > 0) {

		return true;
	    }
	}

	return false;
    }


    public void
    setCity(String cityString)
    {
	Iterator cities = null;
	if ((cities = cityBC().evaluate(null, "MOFW::objects")) == null) {
	    return;
	}

	City city = null;
	while ((city = (City) cities.getNext()) != null) {
	    if (city.getName().equals(cityString)) {
		this.city = city;
		return;
	    }
	}
    }


    public String
    toString()
    {
	return
	    "Name: " + name + "\n" +
	    "Price: " + price + "\n";
    }
}
