package COM.ibm.jaws.models.trs;


import COM.ibm.jaws.mofw.*;
import COM.ibm.jaws.util.*;
import java.util.*;
import COM.ibm.jaws.services.sroot.*;


abstract public class TripBase extends CommonBase
{
    public static Debug d = new Debug("Trip", false);

    public static final String Pending = "Pending";
    public static final String Confirmed = "Confirmed";
    public static final String Taken = "Taken";
    public static final String Cancelled = "Cancelled";

    protected Object backPointer = null;
    protected String name = null;
    protected String status = Pending;

    protected City departureCity = null;
    protected String departureCityString = null;

    protected City destinationCity = null;
    protected String destinationCityString = null;

    protected transient Date departureDate = null;
    protected String departureDateString = null;

    protected transient Date returnDate = null;
    protected String returnDateString = null;

    protected CarReservation carReservation = null;
    protected HotelReservation hotelReservation = null;
    protected FlightReservation departureFlightReservation = null;
    protected FlightReservation returnFlightReservation = null;

    public
    TripBase()
    {
    }


    public
    TripBase(Object backPointer,
	     String name,
	     String departureCityString,
	     String destinationCityString,
	     Date departureDate,
	     Date returnDate)
    {
	this.backPointer = backPointer;
	this.name = name;
	this.departureCityString = departureCityString;
	this.destinationCityString = destinationCityString;
	this.departureDate = new Date(departureDate.getYear(), departureDate.getMonth(), departureDate.getDate());
	this.returnDate = new Date(returnDate.getYear(), returnDate.getMonth(), returnDate.getDate());
	this.status = Pending;
    }


    public void
    activate()
    {
	if (departureDateString != null) {
	    departureDate = stringToDate(departureDateString); //new Date(departureDateString);
	}

	if (returnDateString != null) {
	    returnDate = stringToDate(returnDateString); //new Date(returnDateString);
	}

	if (departureCityString != null) {
	    setDepartureCity(departureCityString);
	    departureCityString = null;
	}

	if (destinationCityString != null) {
	    setDestinationCity(destinationCityString);
	    destinationCityString = null;
	}
    }


    public CarReservation
    reserveCar(CarFleet carFleet,
	       int numberTraveling)
    {
	if (carReservation != null) {
	    d.outln("car was not null: " + carReservation);
	    carReservation.cancel();
	}

	CarReservation carReservationUnmanaged =
	    new CarReservationImpl(self,
				   numberTraveling,
				   carFleet);

	CarReservation carReservationManaged = (CarReservation)
	    carReservationBC().createFromCopy(null,
					      carReservationUnmanaged,
					      null);

	carReservation = carReservationManaged;

	return carReservation;
    }


    public FlightReservation
    reserveDepartureFlight(Flight flight,
			   int numberTraveling,
			   String seat)
    {
	if (departureFlightReservation != null) {
	    departureFlightReservation.cancel();
	}

	departureFlightReservation =
	    addFlightReservation(flight,
				 numberTraveling,
				 seat);

	return departureFlightReservation;
    }


    public HotelReservation
    reserveHotel(RoomGroup roomGroup,
		 int numberTraveling)
    {
	if (hotelReservation != null) {
	    hotelReservation.cancel();
	}

	HotelReservation hotelReservationManageable =
	    new HotelReservationImpl(self,
				     numberTraveling,
				     roomGroup);

	HotelReservation hotelReservationManaged = (HotelReservation)
	    hotelReservationBC().createFromCopy(null,
						hotelReservationManageable,
						null);

	hotelReservation = hotelReservationManaged;
	return hotelReservation;
    }


    public FlightReservation
    reserveReturnFlight(Flight flight,
			int numberTraveling,
			String seat)
    {
	if (returnFlightReservation != null) {
	    returnFlightReservation.cancel();
	}

	returnFlightReservation =
	    addFlightReservation(flight,
				 numberTraveling,
				 seat);
	return returnFlightReservation;
    }


    public void
    cancel()
    {
        cancelDepartureFlightReservation();
        cancelReturnFlightReservation();
        cancelCarReservation();
        cancelHotelReservation();
        status = Cancelled;
    }

    //@BC begin
    public void
    cancelDepartureFlightReservation()
    {
	if (departureFlightReservation != null) {
	    departureFlightReservation.cancel();
	    departureFlightReservation = null;
	}
    }

    public void
    cancelReturnFlightReservation()
    {
	if (returnFlightReservation != null) {
	    returnFlightReservation.cancel();
	    returnFlightReservation = null;
	}
    }

    public void
    cancelCarReservation()
    {
	if (carReservation != null) {
	    carReservation.cancel();
	    carReservation = null;
	}
    }

    public void
    cancelHotelReservation()
    {
	if (hotelReservation != null) {
	    hotelReservation.cancel();
	    hotelReservation = null;
	}
    }
    //@BC end


    public void
    changeDepartureCity(String city)
    {
	setDepartureCity(city);
    }


    public void
    changeDepartureDate(Date date)
    {
	departureDate = new Date(date.getYear(), date.getMonth(), date.getDate());
    }


    public void
    changeDestinationCity(String city)
    {
	setDestinationCity(city);
    }


    public void
    changeName(String newName)
    {
	name = newName;
    }


    public void
    changeReturnDate(Date date)
    {
	returnDate = new Date(date.getYear(), date.getMonth(), date.getDate());
    }


    public void
    confirm(CreditCard creditCard)
    {
	if (departureFlightReservation != null) {
	    departureFlightReservation.confirm(creditCard);
	}

	if (returnFlightReservation != null) {
	    returnFlightReservation.confirm(creditCard);
	}

	if (carReservation != null) {
	    carReservation.confirm(creditCard);
	}

	if (hotelReservation != null) {
	    hotelReservation.confirm(creditCard);
	}

	status = Confirmed;		//@BC
    }


    public Iterator
    getCarFleets(String fleetName)
    {
	Iterator carFleets = null;
	if ((carFleets =
	     carFleetBC().evaluate(null, "MOFW::objects")) == null) {
	    return null;
	}

	String airportCode = destinationCity.getAirport().getCode();
	Vector carFleetAvailabilityVector = new Vector(10, 10);
	CarFleet carFleet = null;
	while ((carFleet = (CarFleet) carFleets.getNext()) != null) {

	    //@BC changed to return all car fleets if fleetName=ALL
            if (carFleet.getAirport().getCode().equals(airportCode) &&
		(carFleet.getName().equals(fleetName) || fleetName.equals("ALL"))
		) {
//@BC if no more available, but we have a reservation, the search will not return it!
//		if (carFleet.available(departureDate, returnDate)) {
		    carFleetAvailabilityVector.addElement(carFleet);
//		}
	    }
	}

	return new RCIteratorImpl(carFleetAvailabilityVector);
    }


    public CarReservation
    getCarReservation()
    {
	d.enter("getCarReservation");
	d.outln("carReservation: " + carReservation);
	d.exit("getCarReservation");
	return carReservation;
    }


    public City
    getDepartureCity()
    {
	return departureCity;
    }


    public City
    getDestinationCity()
    {
	return destinationCity;
    }


    public Date
    getDepartureDate()
    {
	return departureDate;
    }


    public FlightReservation
    getDepartureFlightReservation()
    {
	return departureFlightReservation;
    }


    public Iterator
    getDepartureFlights(String classOfService)
    {
	return getFlights(departureCity.getName(),
			  destinationCity.getName(),
			  departureDate,
			  classOfService);
    }


    public HotelReservation
    getHotelReservation()
    {
	d.enter("getHotelReservation");
	d.outln("hotelReservation: " + hotelReservation);
	d.exit("getHotelReservation");
	return hotelReservation;
    }


    public String
    getName()
    {
	return name;
    }


    public FlightReservation
    getReturnFlightReservation()
    {
	return returnFlightReservation;
    }


    public Date
    getReturnDate()
    {
	return returnDate;
    }


    public Iterator
    getReturnFlights(String classOfService)
    {
	return getFlights(destinationCity.getName(),
			  departureCity.getName(),
			  returnDate,
			  classOfService);
    }


    public Iterator
    getRoomGroups(int maxRate)
    {
	Iterator roomGroups = null;
	if ((roomGroups =
	     roomGroupBC().evaluate(null, "MOFW::objects")) == null) {
	    return null;
	}

	String cityString = destinationCity.getName();
	Vector roomGroupAvailabilityVector = new Vector(10, 10);
	RoomGroup roomGroup = null;
	while ((roomGroup = (RoomGroup) roomGroups.getNext()) != null) {

	    if (roomGroup.getCity().getName().equals(cityString) == false) {
		continue;
	    }

	    if (roomGroup.available(departureDate, returnDate)) {
		roomGroupAvailabilityVector.addElement(roomGroup);
	    }
	}

	return new RCIteratorImpl(roomGroupAvailabilityVector);
    }


    public String
    getStatus()
    {
	return status;
    }

    public void
    setStatus( String s)
    {
        status = s;
    }


    public void
    prepareForExternalization()
    {
	if (departureDate != null) {
	    departureDateString = dateToString(departureDate); //.toGMTString();
	}

	if (returnDate != null) {
	    returnDateString = dateToString(returnDate); //.toGMTString();
	}
    }


    public void
    remove()
    {
	cancel();
    }


    public void
    taken()
    {
	status = Taken;		//@BC

	if (departureFlightReservation != null) {
	    departureFlightReservation.taken();
	}

	if (returnFlightReservation != null) {
	    returnFlightReservation.taken();
	}

	if (carReservation != null) {
	    carReservation.taken();
	}

	if (hotelReservation != null) {
	    hotelReservation.taken();
	}
    }


    public String
    toString()
    {
	return
	    "Name: " + name + "\n" +
	    "DepartureDate: " + departureDate + "\n" +
	    "ReturnDate: " + returnDate + "\n" +
	    "Status: " + status + "\n";
    }


    //-------------------------------------------------------------------------
    // Protected methods


    protected Iterator
    getFlights(String departureCityString,
	       String destinationCityString,
	       Date departureDate,
	       String classOfService)
    {
	Iterator flightPlans = null;
	if ((flightPlans =
	     flightPlanBC().evaluate(null, "MOFW::objects")) == null) {
	    return null;
	}

	Vector flightVector = new Vector(10, 10);
	FlightPlan flightPlan = null;
	while ((flightPlan = (FlightPlan) flightPlans.getNext()) != null) {

	    // See if the flight is going from/to the same cities the user
	    // is interested in.
	    if (flightPlan.getDepartureAirport().getCity().getName().equals
		(departureCityString) &&
		flightPlan.getDestinationAirport().getCity().getName().equals
		(destinationCityString)) {

		// Get the schedule flights between the two airports.
		Iterator flights = null;
		if ((flights = flightPlan.getFlights()) == null) {
		    continue;
		}

		// Check to see if the flight is departing the same day
		// that the user is departing, if so, this is a possible
		// flight.
		Flight flight = null;
		while ((flight = (Flight) flights.getNext()) != null) {
                    Date d = flight.getDepartureDate();
                    if ((d.getYear() == departureDate.getYear()) &&
                        (d.getDate() == departureDate.getDate()) &&
                        (d.getMonth() == departureDate.getMonth())) {
// 012097                    if (flight.getDepartureDate().equals(departureDate)) {
			flightVector.addElement(flight);
		    }
		}
	    }
	}

	return new RCIteratorImpl(flightVector);
    }


    //---------------------------------------------------------------------
    // Protected methods


    protected FlightReservation
    addFlightReservation(Flight flight,
			 int numberTraveling,
			 String seat)
    {
	FlightReservation flightReservation =
	    new FlightReservationImpl(self,
				      numberTraveling,
				      flight,
				      seat);

	FlightReservation flightReservationManaged = (FlightReservation)
	    flightReservationBC().createFromCopy(null,
						 flightReservation,
						 null);
	return flightReservationManaged;
    }


    protected void
    setDepartureCity(String cityString)
    {
	Iterator cities = cityBC().evaluate(null, "MOFW::objects");
	City city = null;
	while ((city = (City) cities.getNext()) != null) {
	    if (city.getName().equals(cityString)) {
		departureCity = city;
		break;
	    }
	}
    }

    protected void
    setDestinationCity(String cityString)
    {
	Iterator cities = cityBC().evaluate(null, "MOFW::objects");
	City city = null;
	while ((city = (City) cities.getNext()) != null) {
	    if (city.getName().equals(cityString)) {
		destinationCity = city;
		break;
	    }
	}
    }

    protected Date stringToDate( String date ) {
	Date d = new Date();
	String c = "";
	StringTokenizer st = new StringTokenizer(date, "|");
	c = st.nextToken();
	d.setMonth( Integer.valueOf(c).intValue() );
	c = st.nextToken();
	d.setDate( Integer.valueOf(c).intValue() );
	c = st.nextToken();
	d.setYear( Integer.valueOf(c).intValue() );
	c = st.nextToken();
	d.setHours( Integer.valueOf(c).intValue() );
	c = st.nextToken();
	d.setMinutes( Integer.valueOf(c).intValue() );
	c = st.nextToken();
	d.setSeconds( Integer.valueOf(c).intValue() );
	//System.out.println("stringToDate -> Date = " + date + " converted date = " + d);
	return d;
    }

    protected String dateToString( Date value) {
	String date = Integer.toString( ((Date)value).getMonth() );
	date = date + "|" + Integer.toString( ((Date)value).getDate() );
	date = date + "|" + Integer.toString( ((Date)value).getYear() );
	date = date + "|" + Integer.toString( ((Date)value).getHours() );
	date = date + "|" + Integer.toString( ((Date)value).getMinutes() );
	date = date + "|" + Integer.toString( ((Date)value).getSeconds() );
	//System.out.println("stringToDate -> date String = " + date + " actual date = " + value);
	return date;
    }

}
