package COM.ibm.jaws.models.trs;


import java.util.*;
import java.net.*;
import COM.ibm.jaws.mofw.*;
import COM.ibm.jaws.util.*;


abstract public class UserBase extends CommonBase
{
    protected static Debug d = new Debug("User", true);

//@BC
    protected String lastName = null;
    protected String firstName = null;
    protected String middleName = null;
    protected String prefix = null;
//@BC

    protected String userId = null;
    protected String password = null;

    protected String socialSecurityNumber = null;

    protected transient Date birthdate = null;
    protected String birthdateString = null;

    protected String driversLicenseNumber = null;
    protected String driversLicenseState = null;

    protected Contact homeContact = null;

    protected String employer = null;
    protected Contact employerContact = null;

    protected TravelProfile travelProfile = null;

    protected ReferenceCollection tripRC = null;



    public
    UserBase()
    {
    }


    public
    UserBase(String lastName,
	     String firstName,
	     String middleName,
	     String prefix,
	     String userId,
	     String password,
	     String socialSecurityNumber,
	     Date birthdate,
	     String driversLicenseNumber,
	     String driversLicenseState)
    {
	this.lastName = lastName;
	this.firstName = firstName;
	this.middleName = middleName;
	this.prefix = prefix;
	this.userId = userId;
	this.password = password;
	this.socialSecurityNumber = socialSecurityNumber;
	this.birthdate = birthdate;
	this.driversLicenseNumber = driversLicenseNumber;
	this.driversLicenseState = driversLicenseState;
    }




    public void
    activate()
    {
	if (birthdateString != null) {
	    birthdate = stringToDate(birthdateString); //new Date(birthdateString);
	}
    }


    public Contact
    addEmployerInformation(String employer,
			   String address1,
			   String address2,
			   String cityString,
			   String zip,
			   String phoneAreaCode,
			   String phoneNumber,
			   String faxAreaCode,
			   String faxNumber,
			   String emailId,
			   String emailAddress,
			   URL url)
    {
	this.employer = employer;

	Contact employerContactManageable =
	    new ContactImpl(self, address1, address2,
			    cityString, zip,
			    phoneAreaCode, phoneNumber,
			    faxAreaCode, faxNumber,
			    emailId, emailAddress, url);

	employerContact =
	    (Contact) contactBC().createFromCopy(null,
						 employerContactManageable,
						 null);

	return employerContact;
    }


    public Contact
    addHomeContact(String address1,
		   String address2,
		   String cityString,
		   String zip,
		   String phoneAreaCode,
		   String phoneNumber,
		   String faxAreaCode,
		   String faxNumber,
		   String emailId,
		   String emailAddress,
		   URL url)
    {
	Contact homeContactManageable =
	    new ContactImpl(self, address1, address2,
			    cityString, zip,
			    phoneAreaCode, phoneNumber,
			    faxAreaCode, faxNumber,
			    emailId, emailAddress, url);

	homeContact =
	    (Contact) contactBC().createFromCopy(null,
						 homeContactManageable,
						 null);

	return homeContact;
    }


    public TravelProfile
    addTravelProfile()
    {
	TravelProfile travelProfileManageable =
	    new TravelProfileImpl(self);

	travelProfile = (TravelProfile)
	    travelProfileBC().createFromCopy(null,
					     travelProfileManageable,
					     null);

	return travelProfile;
    }


    public Trip
    addTrip(String name,
	    String departureCityString,
	    String destinationCityString,
	    Date departureDate,
	    Date returnDate)
    {
	// Implement the lazy create for the local trip reference collection
	// if this is the first trip added for this user.
	if (tripRC == null) {
	    tripRC = (ReferenceCollection)
		userTripRCBC().createFromCopy(null, null, null);
	}

	// New up the manageable object.
	Trip trip = new TripImpl(self, name,
				 departureCityString, destinationCityString,
				 departureDate, returnDate);

	// Manage the object.
	Trip tripManaged =
	    (Trip) tripBC().createFromCopy(null, trip, null);

	// Insert the managed object into the local reference collection.
	tripRC.insertElement(tripManaged);

	return tripManaged;
    }


    public void
    changePassword(String newPassword)
    {
	password = newPassword;
    }


    public Date
    getBirthdate()
    {
	return birthdate;
    }


    public String
    getDriversLicenseNumber()
    {
	return driversLicenseNumber;
    }


    public String
    getDriversLicenseState()
    {
	return driversLicenseState;
    }


    public String
    getEmployer()
    {
	return employer;
    }


    public Contact
    getEmployerContact()
    {
	return employerContact;
    }


    public Contact
    getHomeContact()
    {
	return homeContact;
    }

//@BC
    public String
    getName()
    {
	String n = "";
	if (firstName.length() > 0)
	    n = n + firstName;
	if (middleName.length() > 0) {
	    if (n.length() > 0)
	    	n = n + " ";
	    n = n + middleName;
	}
	if (lastName.length() > 0) {
	    if (n.length() > 0)
	    	n = n + " ";
	    n = n + lastName;
	}
	return n;
    }
//@BC

    public String
    getPassword()
    {
	return password;
    }


    public String
    getSocialSecurityNumber()
    {
	return socialSecurityNumber;
    }


//@BC BEGIN
    public String
    getLastName()
    {
	return lastName;
    }
    public String
    getFirstName()
    {
	return firstName;
    }
    public String
    getMiddleName()
    {
	return middleName;
    }
    public String
    getPrefix()
    {
	return prefix;
    }

    public void
    setFirstName(String d)
    {
	firstName = d;
    }
    public void
    setLastName(String d)
    {
	lastName = d;
    }
    public void
    setMiddleName(String d)
    {
	middleName = d;
    }
    public void
    setPrefix(String d)
    {
	prefix = d;
    }

    public void
    setBirthdate(Date d)
    {
	birthdate = d;
    }

    public void
    setDriversLicenseNumber(String d)
    {
	driversLicenseNumber = d;
    }


    public void
    setDriversLicenseState(String d)
    {
	driversLicenseState = d;
    }


    public void
    setEmployer(String d)
    {
	employer = d;
    }


    public void
    setSocialSecurityNumber(String d)
    {
	socialSecurityNumber = d;
    }

//@BC END


    public TravelProfile
    getTravelProfile()
    {
	return travelProfile;
    }


    public Iterator
    getTrips()
    {
	if (tripRC == null) {
	    return null;
	}

	return tripRC.evaluate(null, "MOFW::Objects");
    }


    public Iterator
    getTrips(String status)
    {
	if (tripRC == null) {
	    return null;
	}

	Iterator trips = null;
	if ((trips = tripRC.evaluate(null, "MOFW::Objects")) == null) {
	    return null;
	}

	Vector tripsMatchingStatusVector = new Vector(10, 10);
	Trip trip = null;
	while ((trip = (Trip) trips.getNext()) != null) {
	    if (trip.getStatus().equals(status)) {
		tripsMatchingStatusVector.addElement(trip);
	    }
	}

	return new RCIteratorImpl(tripsMatchingStatusVector);
    }


    public String
    getUserId()
    {
	return userId;
    }


    public void
    prepareForExternalization()
    {
	if (birthdate != null) {
	    birthdateString = dateToString(birthdate); //.toGMTString();
	}
    }

//@BC
    public String
    toString()
    {
	return
	    "Name: " + prefix + " " + firstName + " " + middleName + " " + lastName + "\n" +
	    "Userid: " + userId + "\n" +
	    "Password: " + password + "\n" +
	    "SocialSecurityNumber: " + socialSecurityNumber + "\n" +
	    "Employer: " + employer + "\n" +
	    "Birthdate: " + birthdate + "\n" +
	    "DriversLicenseNumber: " + driversLicenseNumber + "\n" +
	    "DriversLicenseState: " + driversLicenseState + "\n";
    }

    protected Date stringToDate( String date ) {
	Date d = new Date();
	String c = "";
	StringTokenizer st = new StringTokenizer(date, "|");
	c = st.nextToken();
	d.setMonth( Integer.valueOf(c).intValue() );
	c = st.nextToken();
	d.setDate( Integer.valueOf(c).intValue() );
	c = st.nextToken();
	d.setYear( Integer.valueOf(c).intValue() );
	c = st.nextToken();
	d.setHours( Integer.valueOf(c).intValue() );
	c = st.nextToken();
	d.setMinutes( Integer.valueOf(c).intValue() );
	c = st.nextToken();
	d.setSeconds( Integer.valueOf(c).intValue() );
	//System.out.println("stringToDate -> Date = " + date + " converted date = " + d);
	return d;
    }

    protected String dateToString( Date value) {
	String date = Integer.toString( ((Date)value).getMonth() );
	date = date + "|" + Integer.toString( ((Date)value).getDate() );
	date = date + "|" + Integer.toString( ((Date)value).getYear() );
	date = date + "|" + Integer.toString( ((Date)value).getHours() );
	date = date + "|" + Integer.toString( ((Date)value).getMinutes() );
	date = date + "|" + Integer.toString( ((Date)value).getSeconds() );
	//System.out.println("stringToDate -> date String = " + date + " actual date = " + value);
	return date;
    }

}
