package COM.ibm.jaws.tutorial1;

import COM.ibm.jaws.mofw.BaseCollection;
import COM.ibm.jaws.mofw.NamedCollection;
import COM.ibm.jaws.services.filepobc.FilepoBCImpl;
import COM.ibm.jaws.services.bcfw.Syncable;
import COM.ibm.jaws.services.sroot.SimpleRootBC;
import COM.ibm.jaws.services.sroot.SRootNC;

public class Populate
{
    public static void
    main(String[] args)
    {
	// Verify the command line arguments.
	if (args.length != 3) {
	    System.err.println("Usage: Populate checkingBalance " +
			       "savingsBalance baseDirectory");
	    System.exit(1);
	}

	// Get the arguments from the command line.
	float initialCheckingBalance = Float.valueOf(args[0]).floatValue();
	float initialSavingsBalance = Float.valueOf(args[1]).floatValue();
	String baseDirectory = args[2];

	// Create the activation space directory name.
	String activationSpaceDirectory =
	    baseDirectory + "/accountsActivationSpace";

	// Create the location where the FilepoBC data will be stored.
	String filepoDataDirectory =
	    baseDirectory + "/accountsData";


	// Create the activation space.
	SRootNC dependentContext = new SRootNC();
	dependentContext.addMOEntries
	    ("COM.ibm.jaws.services.filepobc.FilepoBC",
	     "COM.ibm.jaws.services.sroot",
	     "COM.ibm.jaws.services.filepobc.FilepoBCSRootMO");

	BaseCollection activationSpace =
	    new SimpleRootBC(activationSpaceDirectory,
			     dependentContext);
	    

	// Create the FilepoBC database, and add (register) it to the
	// activation space.
	BaseCollection filepoDatabase =
	    new FilepoBCImpl(filepoDataDirectory,
		       "COM.ibm.jaws.tutorial1.AccountFilepoManaged");
			     
	BaseCollection filepoDatabaseManaged = (BaseCollection)
	    activationSpace.createFromCopy
	    ("AccountCollection",
	     filepoDatabase,
	     "COM.ibm.jaws.services.filepobc.FilepoBC");
	

	// Create a checking account and manage it in the database.
	Account checking = new AccountImpl(initialCheckingBalance);
	checking = (Account) filepoDatabaseManaged.createFromCopy
	    ("Checking",
	     checking,
	     "COM.ibm.jaws.tutorial1.Account");
	
	// Create a savings account and manage it in the database.
	Account savings = new AccountImpl(initialSavingsBalance);
	savings = (Account)
	    filepoDatabaseManaged.createFromCopy
	    ("Savings",
	     savings,
	     "COM.ibm.jaws.tutorial1.Account");
	    

	activationSpace.release();
    }
}
